# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['RouteTableArgs', 'RouteTable']

@pulumi.input_type
class RouteTableArgs:
    def __init__(__self__, *,
                 vpc_id: pulumi.Input[builtins.str],
                 associate_type: Optional[pulumi.Input[builtins.str]] = None,
                 custom_route_entries: Optional[pulumi.Input[Sequence[pulumi.Input['RouteTableCustomRouteEntryArgs']]]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 ipv4_gateway_id: Optional[pulumi.Input[builtins.str]] = None,
                 ipv6_gateway_id: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 route_table_name: Optional[pulumi.Input[builtins.str]] = None,
                 subnet_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['RouteTableTagArgs']]]] = None):
        """
        The set of arguments for constructing a RouteTable resource.
        :param pulumi.Input[builtins.str] vpc_id: 路由表所属VPC的ID。
        :param pulumi.Input[builtins.str] associate_type: 创建路由表输入的关联类型。1、Subnet：子网关联。2、Gateway：网关关联。
        :param pulumi.Input[builtins.str] description: 路由表描述信息。
        :param pulumi.Input[builtins.str] ipv4_gateway_id: 关联路由表的IPv4网关ID。
        :param pulumi.Input[builtins.str] ipv6_gateway_id: 关联路由表的IPv6网关ID。
        :param pulumi.Input[builtins.str] project_name: 路由表所属项目的名称。
        :param pulumi.Input[builtins.str] route_table_name: 路由表名称。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] subnet_ids: 关联的子网的ID列表。
        """
        pulumi.set(__self__, "vpc_id", vpc_id)
        if associate_type is not None:
            pulumi.set(__self__, "associate_type", associate_type)
        if custom_route_entries is not None:
            pulumi.set(__self__, "custom_route_entries", custom_route_entries)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if ipv4_gateway_id is not None:
            pulumi.set(__self__, "ipv4_gateway_id", ipv4_gateway_id)
        if ipv6_gateway_id is not None:
            pulumi.set(__self__, "ipv6_gateway_id", ipv6_gateway_id)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if route_table_name is not None:
            pulumi.set(__self__, "route_table_name", route_table_name)
        if subnet_ids is not None:
            pulumi.set(__self__, "subnet_ids", subnet_ids)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Input[builtins.str]:
        """
        路由表所属VPC的ID。
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="associateType")
    def associate_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        创建路由表输入的关联类型。1、Subnet：子网关联。2、Gateway：网关关联。
        """
        return pulumi.get(self, "associate_type")

    @associate_type.setter
    def associate_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "associate_type", value)

    @property
    @pulumi.getter(name="customRouteEntries")
    def custom_route_entries(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RouteTableCustomRouteEntryArgs']]]]:
        return pulumi.get(self, "custom_route_entries")

    @custom_route_entries.setter
    def custom_route_entries(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RouteTableCustomRouteEntryArgs']]]]):
        pulumi.set(self, "custom_route_entries", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        路由表描述信息。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="ipv4GatewayId")
    def ipv4_gateway_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        关联路由表的IPv4网关ID。
        """
        return pulumi.get(self, "ipv4_gateway_id")

    @ipv4_gateway_id.setter
    def ipv4_gateway_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ipv4_gateway_id", value)

    @property
    @pulumi.getter(name="ipv6GatewayId")
    def ipv6_gateway_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        关联路由表的IPv6网关ID。
        """
        return pulumi.get(self, "ipv6_gateway_id")

    @ipv6_gateway_id.setter
    def ipv6_gateway_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ipv6_gateway_id", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        路由表所属项目的名称。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="routeTableName")
    def route_table_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        路由表名称。
        """
        return pulumi.get(self, "route_table_name")

    @route_table_name.setter
    def route_table_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "route_table_name", value)

    @property
    @pulumi.getter(name="subnetIds")
    def subnet_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        关联的子网的ID列表。
        """
        return pulumi.get(self, "subnet_ids")

    @subnet_ids.setter
    def subnet_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "subnet_ids", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RouteTableTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RouteTableTagArgs']]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _RouteTableState:
    def __init__(__self__, *,
                 account_id: Optional[pulumi.Input[builtins.str]] = None,
                 associate_type: Optional[pulumi.Input[builtins.str]] = None,
                 created_time: Optional[pulumi.Input[builtins.str]] = None,
                 custom_route_entries: Optional[pulumi.Input[Sequence[pulumi.Input['RouteTableCustomRouteEntryArgs']]]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 ipv4_gateway_id: Optional[pulumi.Input[builtins.str]] = None,
                 ipv6_gateway_id: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 route_table_id: Optional[pulumi.Input[builtins.str]] = None,
                 route_table_name: Optional[pulumi.Input[builtins.str]] = None,
                 route_table_type: Optional[pulumi.Input[builtins.str]] = None,
                 subnet_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 system_route_entries: Optional[pulumi.Input[Sequence[pulumi.Input['RouteTableSystemRouteEntryArgs']]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['RouteTableTagArgs']]]] = None,
                 updated_time: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering RouteTable resources.
        :param pulumi.Input[builtins.str] account_id: 路由表所属账号的ID。
        :param pulumi.Input[builtins.str] associate_type: 创建路由表输入的关联类型。1、Subnet：子网关联。2、Gateway：网关关联。
        :param pulumi.Input[builtins.str] created_time: 路由表创建时间。
        :param pulumi.Input[builtins.str] description: 路由表描述信息。
        :param pulumi.Input[builtins.str] ipv4_gateway_id: 关联路由表的IPv4网关ID。
        :param pulumi.Input[builtins.str] ipv6_gateway_id: 关联路由表的IPv6网关ID。
        :param pulumi.Input[builtins.str] project_name: 路由表所属项目的名称。
        :param pulumi.Input[builtins.str] route_table_id: 路由表ID。
        :param pulumi.Input[builtins.str] route_table_name: 路由表名称。
        :param pulumi.Input[builtins.str] route_table_type: 路由表类型。1、Custom：自定义路由表。2、System：系统路由表。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] subnet_ids: 关联的子网的ID列表。
        :param pulumi.Input[builtins.str] updated_time: 路由表更新时间。
        :param pulumi.Input[builtins.str] vpc_id: 路由表所属VPC的ID。
        :param pulumi.Input[builtins.str] vpc_name: VPC的名称。
        """
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if associate_type is not None:
            pulumi.set(__self__, "associate_type", associate_type)
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if custom_route_entries is not None:
            pulumi.set(__self__, "custom_route_entries", custom_route_entries)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if ipv4_gateway_id is not None:
            pulumi.set(__self__, "ipv4_gateway_id", ipv4_gateway_id)
        if ipv6_gateway_id is not None:
            pulumi.set(__self__, "ipv6_gateway_id", ipv6_gateway_id)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if route_table_id is not None:
            pulumi.set(__self__, "route_table_id", route_table_id)
        if route_table_name is not None:
            pulumi.set(__self__, "route_table_name", route_table_name)
        if route_table_type is not None:
            pulumi.set(__self__, "route_table_type", route_table_type)
        if subnet_ids is not None:
            pulumi.set(__self__, "subnet_ids", subnet_ids)
        if system_route_entries is not None:
            pulumi.set(__self__, "system_route_entries", system_route_entries)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if updated_time is not None:
            pulumi.set(__self__, "updated_time", updated_time)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)
        if vpc_name is not None:
            pulumi.set(__self__, "vpc_name", vpc_name)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        路由表所属账号的ID。
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "account_id", value)

    @property
    @pulumi.getter(name="associateType")
    def associate_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        创建路由表输入的关联类型。1、Subnet：子网关联。2、Gateway：网关关联。
        """
        return pulumi.get(self, "associate_type")

    @associate_type.setter
    def associate_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "associate_type", value)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        路由表创建时间。
        """
        return pulumi.get(self, "created_time")

    @created_time.setter
    def created_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_time", value)

    @property
    @pulumi.getter(name="customRouteEntries")
    def custom_route_entries(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RouteTableCustomRouteEntryArgs']]]]:
        return pulumi.get(self, "custom_route_entries")

    @custom_route_entries.setter
    def custom_route_entries(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RouteTableCustomRouteEntryArgs']]]]):
        pulumi.set(self, "custom_route_entries", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        路由表描述信息。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="ipv4GatewayId")
    def ipv4_gateway_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        关联路由表的IPv4网关ID。
        """
        return pulumi.get(self, "ipv4_gateway_id")

    @ipv4_gateway_id.setter
    def ipv4_gateway_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ipv4_gateway_id", value)

    @property
    @pulumi.getter(name="ipv6GatewayId")
    def ipv6_gateway_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        关联路由表的IPv6网关ID。
        """
        return pulumi.get(self, "ipv6_gateway_id")

    @ipv6_gateway_id.setter
    def ipv6_gateway_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ipv6_gateway_id", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        路由表所属项目的名称。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="routeTableId")
    def route_table_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        路由表ID。
        """
        return pulumi.get(self, "route_table_id")

    @route_table_id.setter
    def route_table_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "route_table_id", value)

    @property
    @pulumi.getter(name="routeTableName")
    def route_table_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        路由表名称。
        """
        return pulumi.get(self, "route_table_name")

    @route_table_name.setter
    def route_table_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "route_table_name", value)

    @property
    @pulumi.getter(name="routeTableType")
    def route_table_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        路由表类型。1、Custom：自定义路由表。2、System：系统路由表。
        """
        return pulumi.get(self, "route_table_type")

    @route_table_type.setter
    def route_table_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "route_table_type", value)

    @property
    @pulumi.getter(name="subnetIds")
    def subnet_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        关联的子网的ID列表。
        """
        return pulumi.get(self, "subnet_ids")

    @subnet_ids.setter
    def subnet_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "subnet_ids", value)

    @property
    @pulumi.getter(name="systemRouteEntries")
    def system_route_entries(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RouteTableSystemRouteEntryArgs']]]]:
        return pulumi.get(self, "system_route_entries")

    @system_route_entries.setter
    def system_route_entries(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RouteTableSystemRouteEntryArgs']]]]):
        pulumi.set(self, "system_route_entries", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RouteTableTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RouteTableTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        路由表更新时间。
        """
        return pulumi.get(self, "updated_time")

    @updated_time.setter
    def updated_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_time", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        路由表所属VPC的ID。
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="vpcName")
    def vpc_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPC的名称。
        """
        return pulumi.get(self, "vpc_name")

    @vpc_name.setter
    def vpc_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vpc_name", value)


@pulumi.type_token("bytepluscc:vpc/routeTable:RouteTable")
class RouteTable(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 associate_type: Optional[pulumi.Input[builtins.str]] = None,
                 custom_route_entries: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RouteTableCustomRouteEntryArgs', 'RouteTableCustomRouteEntryArgsDict']]]]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 ipv4_gateway_id: Optional[pulumi.Input[builtins.str]] = None,
                 ipv6_gateway_id: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 route_table_name: Optional[pulumi.Input[builtins.str]] = None,
                 subnet_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RouteTableTagArgs', 'RouteTableTagArgsDict']]]]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        路由表由一系列路由条目组成，为私有网络的流量指定下一跳的云资源，每个子网必须且仅支持关联一个路由表，使子网内的资源通过路由表转发流量。

        ## Import

        ```sh
        $ pulumi import bytepluscc:vpc/routeTable:RouteTable example "route_table_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] associate_type: 创建路由表输入的关联类型。1、Subnet：子网关联。2、Gateway：网关关联。
        :param pulumi.Input[builtins.str] description: 路由表描述信息。
        :param pulumi.Input[builtins.str] ipv4_gateway_id: 关联路由表的IPv4网关ID。
        :param pulumi.Input[builtins.str] ipv6_gateway_id: 关联路由表的IPv6网关ID。
        :param pulumi.Input[builtins.str] project_name: 路由表所属项目的名称。
        :param pulumi.Input[builtins.str] route_table_name: 路由表名称。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] subnet_ids: 关联的子网的ID列表。
        :param pulumi.Input[builtins.str] vpc_id: 路由表所属VPC的ID。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RouteTableArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        路由表由一系列路由条目组成，为私有网络的流量指定下一跳的云资源，每个子网必须且仅支持关联一个路由表，使子网内的资源通过路由表转发流量。

        ## Import

        ```sh
        $ pulumi import bytepluscc:vpc/routeTable:RouteTable example "route_table_id"
        ```

        :param str resource_name: The name of the resource.
        :param RouteTableArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RouteTableArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 associate_type: Optional[pulumi.Input[builtins.str]] = None,
                 custom_route_entries: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RouteTableCustomRouteEntryArgs', 'RouteTableCustomRouteEntryArgsDict']]]]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 ipv4_gateway_id: Optional[pulumi.Input[builtins.str]] = None,
                 ipv6_gateway_id: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 route_table_name: Optional[pulumi.Input[builtins.str]] = None,
                 subnet_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RouteTableTagArgs', 'RouteTableTagArgsDict']]]]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RouteTableArgs.__new__(RouteTableArgs)

            __props__.__dict__["associate_type"] = associate_type
            __props__.__dict__["custom_route_entries"] = custom_route_entries
            __props__.__dict__["description"] = description
            __props__.__dict__["ipv4_gateway_id"] = ipv4_gateway_id
            __props__.__dict__["ipv6_gateway_id"] = ipv6_gateway_id
            __props__.__dict__["project_name"] = project_name
            __props__.__dict__["route_table_name"] = route_table_name
            __props__.__dict__["subnet_ids"] = subnet_ids
            __props__.__dict__["tags"] = tags
            if vpc_id is None and not opts.urn:
                raise TypeError("Missing required property 'vpc_id'")
            __props__.__dict__["vpc_id"] = vpc_id
            __props__.__dict__["account_id"] = None
            __props__.__dict__["created_time"] = None
            __props__.__dict__["route_table_id"] = None
            __props__.__dict__["route_table_type"] = None
            __props__.__dict__["system_route_entries"] = None
            __props__.__dict__["updated_time"] = None
            __props__.__dict__["vpc_name"] = None
        super(RouteTable, __self__).__init__(
            'bytepluscc:vpc/routeTable:RouteTable',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_id: Optional[pulumi.Input[builtins.str]] = None,
            associate_type: Optional[pulumi.Input[builtins.str]] = None,
            created_time: Optional[pulumi.Input[builtins.str]] = None,
            custom_route_entries: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RouteTableCustomRouteEntryArgs', 'RouteTableCustomRouteEntryArgsDict']]]]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            ipv4_gateway_id: Optional[pulumi.Input[builtins.str]] = None,
            ipv6_gateway_id: Optional[pulumi.Input[builtins.str]] = None,
            project_name: Optional[pulumi.Input[builtins.str]] = None,
            route_table_id: Optional[pulumi.Input[builtins.str]] = None,
            route_table_name: Optional[pulumi.Input[builtins.str]] = None,
            route_table_type: Optional[pulumi.Input[builtins.str]] = None,
            subnet_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            system_route_entries: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RouteTableSystemRouteEntryArgs', 'RouteTableSystemRouteEntryArgsDict']]]]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RouteTableTagArgs', 'RouteTableTagArgsDict']]]]] = None,
            updated_time: Optional[pulumi.Input[builtins.str]] = None,
            vpc_id: Optional[pulumi.Input[builtins.str]] = None,
            vpc_name: Optional[pulumi.Input[builtins.str]] = None) -> 'RouteTable':
        """
        Get an existing RouteTable resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] account_id: 路由表所属账号的ID。
        :param pulumi.Input[builtins.str] associate_type: 创建路由表输入的关联类型。1、Subnet：子网关联。2、Gateway：网关关联。
        :param pulumi.Input[builtins.str] created_time: 路由表创建时间。
        :param pulumi.Input[builtins.str] description: 路由表描述信息。
        :param pulumi.Input[builtins.str] ipv4_gateway_id: 关联路由表的IPv4网关ID。
        :param pulumi.Input[builtins.str] ipv6_gateway_id: 关联路由表的IPv6网关ID。
        :param pulumi.Input[builtins.str] project_name: 路由表所属项目的名称。
        :param pulumi.Input[builtins.str] route_table_id: 路由表ID。
        :param pulumi.Input[builtins.str] route_table_name: 路由表名称。
        :param pulumi.Input[builtins.str] route_table_type: 路由表类型。1、Custom：自定义路由表。2、System：系统路由表。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] subnet_ids: 关联的子网的ID列表。
        :param pulumi.Input[builtins.str] updated_time: 路由表更新时间。
        :param pulumi.Input[builtins.str] vpc_id: 路由表所属VPC的ID。
        :param pulumi.Input[builtins.str] vpc_name: VPC的名称。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RouteTableState.__new__(_RouteTableState)

        __props__.__dict__["account_id"] = account_id
        __props__.__dict__["associate_type"] = associate_type
        __props__.__dict__["created_time"] = created_time
        __props__.__dict__["custom_route_entries"] = custom_route_entries
        __props__.__dict__["description"] = description
        __props__.__dict__["ipv4_gateway_id"] = ipv4_gateway_id
        __props__.__dict__["ipv6_gateway_id"] = ipv6_gateway_id
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["route_table_id"] = route_table_id
        __props__.__dict__["route_table_name"] = route_table_name
        __props__.__dict__["route_table_type"] = route_table_type
        __props__.__dict__["subnet_ids"] = subnet_ids
        __props__.__dict__["system_route_entries"] = system_route_entries
        __props__.__dict__["tags"] = tags
        __props__.__dict__["updated_time"] = updated_time
        __props__.__dict__["vpc_id"] = vpc_id
        __props__.__dict__["vpc_name"] = vpc_name
        return RouteTable(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Output[builtins.str]:
        """
        路由表所属账号的ID。
        """
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter(name="associateType")
    def associate_type(self) -> pulumi.Output[builtins.str]:
        """
        创建路由表输入的关联类型。1、Subnet：子网关联。2、Gateway：网关关联。
        """
        return pulumi.get(self, "associate_type")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> pulumi.Output[builtins.str]:
        """
        路由表创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter(name="customRouteEntries")
    def custom_route_entries(self) -> pulumi.Output[Sequence['outputs.RouteTableCustomRouteEntry']]:
        return pulumi.get(self, "custom_route_entries")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        路由表描述信息。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="ipv4GatewayId")
    def ipv4_gateway_id(self) -> pulumi.Output[builtins.str]:
        """
        关联路由表的IPv4网关ID。
        """
        return pulumi.get(self, "ipv4_gateway_id")

    @property
    @pulumi.getter(name="ipv6GatewayId")
    def ipv6_gateway_id(self) -> pulumi.Output[builtins.str]:
        """
        关联路由表的IPv6网关ID。
        """
        return pulumi.get(self, "ipv6_gateway_id")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[builtins.str]:
        """
        路由表所属项目的名称。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="routeTableId")
    def route_table_id(self) -> pulumi.Output[builtins.str]:
        """
        路由表ID。
        """
        return pulumi.get(self, "route_table_id")

    @property
    @pulumi.getter(name="routeTableName")
    def route_table_name(self) -> pulumi.Output[builtins.str]:
        """
        路由表名称。
        """
        return pulumi.get(self, "route_table_name")

    @property
    @pulumi.getter(name="routeTableType")
    def route_table_type(self) -> pulumi.Output[builtins.str]:
        """
        路由表类型。1、Custom：自定义路由表。2、System：系统路由表。
        """
        return pulumi.get(self, "route_table_type")

    @property
    @pulumi.getter(name="subnetIds")
    def subnet_ids(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        关联的子网的ID列表。
        """
        return pulumi.get(self, "subnet_ids")

    @property
    @pulumi.getter(name="systemRouteEntries")
    def system_route_entries(self) -> pulumi.Output[Sequence['outputs.RouteTableSystemRouteEntry']]:
        return pulumi.get(self, "system_route_entries")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.RouteTableTag']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> pulumi.Output[builtins.str]:
        """
        路由表更新时间。
        """
        return pulumi.get(self, "updated_time")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Output[builtins.str]:
        """
        路由表所属VPC的ID。
        """
        return pulumi.get(self, "vpc_id")

    @property
    @pulumi.getter(name="vpcName")
    def vpc_name(self) -> pulumi.Output[builtins.str]:
        """
        VPC的名称。
        """
        return pulumi.get(self, "vpc_name")

