# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['VpnGatewayArgs', 'VpnGateway']

@pulumi.input_type
class VpnGatewayArgs:
    def __init__(__self__, *,
                 bandwidth: pulumi.Input[builtins.int],
                 subnet_id: pulumi.Input[builtins.str],
                 vpc_id: pulumi.Input[builtins.str],
                 asn: Optional[pulumi.Input[builtins.int]] = None,
                 billing_type: Optional[pulumi.Input[builtins.int]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 dual_tunnel_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 ip_stack_type: Optional[pulumi.Input[builtins.str]] = None,
                 ip_version: Optional[pulumi.Input[builtins.str]] = None,
                 ipsec_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 period: Optional[pulumi.Input[builtins.int]] = None,
                 period_unit: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 secondary_subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 ssl_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 ssl_max_connections: Optional[pulumi.Input[builtins.int]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['VpnGatewayTagArgs']]]] = None,
                 vpn_gateway_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a VpnGateway resource.
        :param pulumi.Input[builtins.int] bandwidth: VPN网关的带宽规格。
        :param pulumi.Input[builtins.str] subnet_id: VPN网关使用的端口所属子网的ID。
        :param pulumi.Input[builtins.str] vpc_id: VPN网关所在VPC的ID。
        :param pulumi.Input[builtins.int] asn: VPN网关的ASN。
        :param pulumi.Input[builtins.int] billing_type: VPN网关的计费类型。1：包年包月。2：按量计费（按固定规格）
        :param pulumi.Input[builtins.str] description: VPN网关的描述。
        :param pulumi.Input[builtins.bool] dual_tunnel_enabled: VPN网关是否开启双隧道模式。true：开启false：关闭
        :param pulumi.Input[builtins.str] ip_stack_type: VPN 网关的协议类型。ipv4*only：IPv4协议类型。ipv6*only：IPv6协议类型。ipv4_ipv6：双栈协议类型。
        :param pulumi.Input[builtins.str] ip_version: VPN网关的IP地址类型。ipv4：IPv4地址类型。ipv6：IPv6地址类型。
        :param pulumi.Input[builtins.bool] ipsec_enabled: 是否开启IPSec功能。true：开启false：关闭。
        :param pulumi.Input[builtins.int] period: 包年包月类型VPN网关购买的时长，默认“1”。当PeriodUnit传入值为Month，Period取值范围：1~9、12、24、36。当PeriodUnit传入值为Year，Period取值范围：1～3。
        :param pulumi.Input[builtins.str] period_unit: 包年包月类型VPN网关购买时长的单位，默认“Month”。Month：月Year：年
        :param pulumi.Input[builtins.str] project_name: VPN网关所属的项目。不填默认为default，即创建的资源属于default项目。您可调用ListProjects查询当前账号下项目的信息。
        :param pulumi.Input[builtins.str] secondary_subnet_id: VPN网关实例关联的第二个子网的ID。仅双隧道模式的VPN网关实例返回该参数，单隧道模式的VPN网关实例不返回该参数。
        :param pulumi.Input[builtins.bool] ssl_enabled: 是否开启SSL VPN功能。true：开启false：关闭
        :param pulumi.Input[builtins.int] ssl_max_connections: VPN网关的最大SSL连接数。
        :param pulumi.Input[builtins.str] vpn_gateway_name: VPN网关的名称。
        """
        pulumi.set(__self__, "bandwidth", bandwidth)
        pulumi.set(__self__, "subnet_id", subnet_id)
        pulumi.set(__self__, "vpc_id", vpc_id)
        if asn is not None:
            pulumi.set(__self__, "asn", asn)
        if billing_type is not None:
            pulumi.set(__self__, "billing_type", billing_type)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if dual_tunnel_enabled is not None:
            pulumi.set(__self__, "dual_tunnel_enabled", dual_tunnel_enabled)
        if ip_stack_type is not None:
            pulumi.set(__self__, "ip_stack_type", ip_stack_type)
        if ip_version is not None:
            pulumi.set(__self__, "ip_version", ip_version)
        if ipsec_enabled is not None:
            pulumi.set(__self__, "ipsec_enabled", ipsec_enabled)
        if period is not None:
            pulumi.set(__self__, "period", period)
        if period_unit is not None:
            pulumi.set(__self__, "period_unit", period_unit)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if secondary_subnet_id is not None:
            pulumi.set(__self__, "secondary_subnet_id", secondary_subnet_id)
        if ssl_enabled is not None:
            pulumi.set(__self__, "ssl_enabled", ssl_enabled)
        if ssl_max_connections is not None:
            pulumi.set(__self__, "ssl_max_connections", ssl_max_connections)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if vpn_gateway_name is not None:
            pulumi.set(__self__, "vpn_gateway_name", vpn_gateway_name)

    @property
    @pulumi.getter
    def bandwidth(self) -> pulumi.Input[builtins.int]:
        """
        VPN网关的带宽规格。
        """
        return pulumi.get(self, "bandwidth")

    @bandwidth.setter
    def bandwidth(self, value: pulumi.Input[builtins.int]):
        pulumi.set(self, "bandwidth", value)

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> pulumi.Input[builtins.str]:
        """
        VPN网关使用的端口所属子网的ID。
        """
        return pulumi.get(self, "subnet_id")

    @subnet_id.setter
    def subnet_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "subnet_id", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Input[builtins.str]:
        """
        VPN网关所在VPC的ID。
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter
    def asn(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        VPN网关的ASN。
        """
        return pulumi.get(self, "asn")

    @asn.setter
    def asn(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "asn", value)

    @property
    @pulumi.getter(name="billingType")
    def billing_type(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        VPN网关的计费类型。1：包年包月。2：按量计费（按固定规格）
        """
        return pulumi.get(self, "billing_type")

    @billing_type.setter
    def billing_type(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "billing_type", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPN网关的描述。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="dualTunnelEnabled")
    def dual_tunnel_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        VPN网关是否开启双隧道模式。true：开启false：关闭
        """
        return pulumi.get(self, "dual_tunnel_enabled")

    @dual_tunnel_enabled.setter
    def dual_tunnel_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "dual_tunnel_enabled", value)

    @property
    @pulumi.getter(name="ipStackType")
    def ip_stack_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPN 网关的协议类型。ipv4*only：IPv4协议类型。ipv6*only：IPv6协议类型。ipv4_ipv6：双栈协议类型。
        """
        return pulumi.get(self, "ip_stack_type")

    @ip_stack_type.setter
    def ip_stack_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ip_stack_type", value)

    @property
    @pulumi.getter(name="ipVersion")
    def ip_version(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPN网关的IP地址类型。ipv4：IPv4地址类型。ipv6：IPv6地址类型。
        """
        return pulumi.get(self, "ip_version")

    @ip_version.setter
    def ip_version(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ip_version", value)

    @property
    @pulumi.getter(name="ipsecEnabled")
    def ipsec_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启IPSec功能。true：开启false：关闭。
        """
        return pulumi.get(self, "ipsec_enabled")

    @ipsec_enabled.setter
    def ipsec_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "ipsec_enabled", value)

    @property
    @pulumi.getter
    def period(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        包年包月类型VPN网关购买的时长，默认“1”。当PeriodUnit传入值为Month，Period取值范围：1~9、12、24、36。当PeriodUnit传入值为Year，Period取值范围：1～3。
        """
        return pulumi.get(self, "period")

    @period.setter
    def period(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "period", value)

    @property
    @pulumi.getter(name="periodUnit")
    def period_unit(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        包年包月类型VPN网关购买时长的单位，默认“Month”。Month：月Year：年
        """
        return pulumi.get(self, "period_unit")

    @period_unit.setter
    def period_unit(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "period_unit", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPN网关所属的项目。不填默认为default，即创建的资源属于default项目。您可调用ListProjects查询当前账号下项目的信息。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="secondarySubnetId")
    def secondary_subnet_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPN网关实例关联的第二个子网的ID。仅双隧道模式的VPN网关实例返回该参数，单隧道模式的VPN网关实例不返回该参数。
        """
        return pulumi.get(self, "secondary_subnet_id")

    @secondary_subnet_id.setter
    def secondary_subnet_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "secondary_subnet_id", value)

    @property
    @pulumi.getter(name="sslEnabled")
    def ssl_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启SSL VPN功能。true：开启false：关闭
        """
        return pulumi.get(self, "ssl_enabled")

    @ssl_enabled.setter
    def ssl_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "ssl_enabled", value)

    @property
    @pulumi.getter(name="sslMaxConnections")
    def ssl_max_connections(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        VPN网关的最大SSL连接数。
        """
        return pulumi.get(self, "ssl_max_connections")

    @ssl_max_connections.setter
    def ssl_max_connections(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "ssl_max_connections", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['VpnGatewayTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['VpnGatewayTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="vpnGatewayName")
    def vpn_gateway_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPN网关的名称。
        """
        return pulumi.get(self, "vpn_gateway_name")

    @vpn_gateway_name.setter
    def vpn_gateway_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vpn_gateway_name", value)


@pulumi.input_type
class _VpnGatewayState:
    def __init__(__self__, *,
                 asn: Optional[pulumi.Input[builtins.int]] = None,
                 bandwidth: Optional[pulumi.Input[builtins.int]] = None,
                 billing_type: Optional[pulumi.Input[builtins.int]] = None,
                 business_status: Optional[pulumi.Input[builtins.str]] = None,
                 connection_count: Optional[pulumi.Input[builtins.int]] = None,
                 create_time: Optional[pulumi.Input[builtins.str]] = None,
                 deleted_time: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 dual_tunnel_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 expired_time: Optional[pulumi.Input[builtins.str]] = None,
                 ip_address: Optional[pulumi.Input[builtins.str]] = None,
                 ip_stack_type: Optional[pulumi.Input[builtins.str]] = None,
                 ip_version: Optional[pulumi.Input[builtins.str]] = None,
                 ipsec_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 is_blocked: Optional[pulumi.Input[builtins.bool]] = None,
                 lock_reason: Optional[pulumi.Input[builtins.str]] = None,
                 overdue_time: Optional[pulumi.Input[builtins.str]] = None,
                 period: Optional[pulumi.Input[builtins.int]] = None,
                 period_unit: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 route_count: Optional[pulumi.Input[builtins.int]] = None,
                 secondary_ip_address: Optional[pulumi.Input[builtins.str]] = None,
                 secondary_subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 ssl_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 ssl_max_connections: Optional[pulumi.Input[builtins.int]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['VpnGatewayTagArgs']]]] = None,
                 update_time: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 vpn_gateway_id: Optional[pulumi.Input[builtins.str]] = None,
                 vpn_gateway_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering VpnGateway resources.
        :param pulumi.Input[builtins.int] asn: VPN网关的ASN。
        :param pulumi.Input[builtins.int] bandwidth: VPN网关的带宽规格。
        :param pulumi.Input[builtins.int] billing_type: VPN网关的计费类型。1：包年包月。2：按量计费（按固定规格）
        :param pulumi.Input[builtins.str] business_status: VPN网关的计费状态。Normal: 正常。FinancialLocked: 被锁定。
        :param pulumi.Input[builtins.int] connection_count: VPN网关关联IPsec连接的数量。
        :param pulumi.Input[builtins.str] create_time: 创建VPN网关的时间。
        :param pulumi.Input[builtins.str] deleted_time: 预期资源强制回收时间。
        :param pulumi.Input[builtins.str] description: VPN网关的描述。
        :param pulumi.Input[builtins.bool] dual_tunnel_enabled: VPN网关是否开启双隧道模式。true：开启false：关闭
        :param pulumi.Input[builtins.str] expired_time: VPN网关的到期时间。
        :param pulumi.Input[builtins.str] ip_address: VPN网关的公网IP地址。
        :param pulumi.Input[builtins.str] ip_stack_type: VPN 网关的协议类型。ipv4*only：IPv4协议类型。ipv6*only：IPv6协议类型。ipv4_ipv6：双栈协议类型。
        :param pulumi.Input[builtins.str] ip_version: VPN网关的IP地址类型。ipv4：IPv4地址类型。ipv6：IPv6地址类型。
        :param pulumi.Input[builtins.bool] ipsec_enabled: 是否开启IPSec功能。true：开启false：关闭。
        :param pulumi.Input[builtins.bool] is_blocked: 当前资源的状态是否被封禁。true：封禁false：未封禁。
        :param pulumi.Input[builtins.str] lock_reason: VPN网关的锁定原因。financial：因欠费被锁定。security：因安全被锁定。unlock：未锁定。
        :param pulumi.Input[builtins.str] overdue_time: 资源冻结时间。仅当资源因为欠费冻结，此参数才会有返回值，否则均返回空值。
        :param pulumi.Input[builtins.int] period: 包年包月类型VPN网关购买的时长，默认“1”。当PeriodUnit传入值为Month，Period取值范围：1~9、12、24、36。当PeriodUnit传入值为Year，Period取值范围：1～3。
        :param pulumi.Input[builtins.str] period_unit: 包年包月类型VPN网关购买时长的单位，默认“Month”。Month：月Year：年
        :param pulumi.Input[builtins.str] project_name: VPN网关所属的项目。不填默认为default，即创建的资源属于default项目。您可调用ListProjects查询当前账号下项目的信息。
        :param pulumi.Input[builtins.int] route_count: VPN网关的路由条目数量。
        :param pulumi.Input[builtins.str] secondary_ip_address: VPN网关的第二个公网IP地址。仅双隧道模式的VPN网关实例返回该参数，单隧道模式的VPN网关实例不返回该参数。
        :param pulumi.Input[builtins.str] secondary_subnet_id: VPN网关实例关联的第二个子网的ID。仅双隧道模式的VPN网关实例返回该参数，单隧道模式的VPN网关实例不返回该参数。
        :param pulumi.Input[builtins.bool] ssl_enabled: 是否开启SSL VPN功能。true：开启false：关闭
        :param pulumi.Input[builtins.int] ssl_max_connections: VPN网关的最大SSL连接数。
        :param pulumi.Input[builtins.str] status: VPN网关的状态。Creating: 创建中Deleting: 删除中Pending：配置中Available：可用
        :param pulumi.Input[builtins.str] subnet_id: VPN网关使用的端口所属子网的ID。
        :param pulumi.Input[builtins.str] update_time: 更新VPN网关的时间。
        :param pulumi.Input[builtins.str] vpc_id: VPN网关所在VPC的ID。
        :param pulumi.Input[builtins.str] vpn_gateway_id: VPN网关的ID。
        :param pulumi.Input[builtins.str] vpn_gateway_name: VPN网关的名称。
        """
        if asn is not None:
            pulumi.set(__self__, "asn", asn)
        if bandwidth is not None:
            pulumi.set(__self__, "bandwidth", bandwidth)
        if billing_type is not None:
            pulumi.set(__self__, "billing_type", billing_type)
        if business_status is not None:
            pulumi.set(__self__, "business_status", business_status)
        if connection_count is not None:
            pulumi.set(__self__, "connection_count", connection_count)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if deleted_time is not None:
            pulumi.set(__self__, "deleted_time", deleted_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if dual_tunnel_enabled is not None:
            pulumi.set(__self__, "dual_tunnel_enabled", dual_tunnel_enabled)
        if expired_time is not None:
            pulumi.set(__self__, "expired_time", expired_time)
        if ip_address is not None:
            pulumi.set(__self__, "ip_address", ip_address)
        if ip_stack_type is not None:
            pulumi.set(__self__, "ip_stack_type", ip_stack_type)
        if ip_version is not None:
            pulumi.set(__self__, "ip_version", ip_version)
        if ipsec_enabled is not None:
            pulumi.set(__self__, "ipsec_enabled", ipsec_enabled)
        if is_blocked is not None:
            pulumi.set(__self__, "is_blocked", is_blocked)
        if lock_reason is not None:
            pulumi.set(__self__, "lock_reason", lock_reason)
        if overdue_time is not None:
            pulumi.set(__self__, "overdue_time", overdue_time)
        if period is not None:
            pulumi.set(__self__, "period", period)
        if period_unit is not None:
            pulumi.set(__self__, "period_unit", period_unit)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if route_count is not None:
            pulumi.set(__self__, "route_count", route_count)
        if secondary_ip_address is not None:
            pulumi.set(__self__, "secondary_ip_address", secondary_ip_address)
        if secondary_subnet_id is not None:
            pulumi.set(__self__, "secondary_subnet_id", secondary_subnet_id)
        if ssl_enabled is not None:
            pulumi.set(__self__, "ssl_enabled", ssl_enabled)
        if ssl_max_connections is not None:
            pulumi.set(__self__, "ssl_max_connections", ssl_max_connections)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if subnet_id is not None:
            pulumi.set(__self__, "subnet_id", subnet_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if update_time is not None:
            pulumi.set(__self__, "update_time", update_time)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)
        if vpn_gateway_id is not None:
            pulumi.set(__self__, "vpn_gateway_id", vpn_gateway_id)
        if vpn_gateway_name is not None:
            pulumi.set(__self__, "vpn_gateway_name", vpn_gateway_name)

    @property
    @pulumi.getter
    def asn(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        VPN网关的ASN。
        """
        return pulumi.get(self, "asn")

    @asn.setter
    def asn(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "asn", value)

    @property
    @pulumi.getter
    def bandwidth(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        VPN网关的带宽规格。
        """
        return pulumi.get(self, "bandwidth")

    @bandwidth.setter
    def bandwidth(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "bandwidth", value)

    @property
    @pulumi.getter(name="billingType")
    def billing_type(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        VPN网关的计费类型。1：包年包月。2：按量计费（按固定规格）
        """
        return pulumi.get(self, "billing_type")

    @billing_type.setter
    def billing_type(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "billing_type", value)

    @property
    @pulumi.getter(name="businessStatus")
    def business_status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPN网关的计费状态。Normal: 正常。FinancialLocked: 被锁定。
        """
        return pulumi.get(self, "business_status")

    @business_status.setter
    def business_status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "business_status", value)

    @property
    @pulumi.getter(name="connectionCount")
    def connection_count(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        VPN网关关联IPsec连接的数量。
        """
        return pulumi.get(self, "connection_count")

    @connection_count.setter
    def connection_count(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "connection_count", value)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        创建VPN网关的时间。
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="deletedTime")
    def deleted_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        预期资源强制回收时间。
        """
        return pulumi.get(self, "deleted_time")

    @deleted_time.setter
    def deleted_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "deleted_time", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPN网关的描述。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="dualTunnelEnabled")
    def dual_tunnel_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        VPN网关是否开启双隧道模式。true：开启false：关闭
        """
        return pulumi.get(self, "dual_tunnel_enabled")

    @dual_tunnel_enabled.setter
    def dual_tunnel_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "dual_tunnel_enabled", value)

    @property
    @pulumi.getter(name="expiredTime")
    def expired_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPN网关的到期时间。
        """
        return pulumi.get(self, "expired_time")

    @expired_time.setter
    def expired_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "expired_time", value)

    @property
    @pulumi.getter(name="ipAddress")
    def ip_address(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPN网关的公网IP地址。
        """
        return pulumi.get(self, "ip_address")

    @ip_address.setter
    def ip_address(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ip_address", value)

    @property
    @pulumi.getter(name="ipStackType")
    def ip_stack_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPN 网关的协议类型。ipv4*only：IPv4协议类型。ipv6*only：IPv6协议类型。ipv4_ipv6：双栈协议类型。
        """
        return pulumi.get(self, "ip_stack_type")

    @ip_stack_type.setter
    def ip_stack_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ip_stack_type", value)

    @property
    @pulumi.getter(name="ipVersion")
    def ip_version(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPN网关的IP地址类型。ipv4：IPv4地址类型。ipv6：IPv6地址类型。
        """
        return pulumi.get(self, "ip_version")

    @ip_version.setter
    def ip_version(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ip_version", value)

    @property
    @pulumi.getter(name="ipsecEnabled")
    def ipsec_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启IPSec功能。true：开启false：关闭。
        """
        return pulumi.get(self, "ipsec_enabled")

    @ipsec_enabled.setter
    def ipsec_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "ipsec_enabled", value)

    @property
    @pulumi.getter(name="isBlocked")
    def is_blocked(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        当前资源的状态是否被封禁。true：封禁false：未封禁。
        """
        return pulumi.get(self, "is_blocked")

    @is_blocked.setter
    def is_blocked(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "is_blocked", value)

    @property
    @pulumi.getter(name="lockReason")
    def lock_reason(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPN网关的锁定原因。financial：因欠费被锁定。security：因安全被锁定。unlock：未锁定。
        """
        return pulumi.get(self, "lock_reason")

    @lock_reason.setter
    def lock_reason(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "lock_reason", value)

    @property
    @pulumi.getter(name="overdueTime")
    def overdue_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        资源冻结时间。仅当资源因为欠费冻结，此参数才会有返回值，否则均返回空值。
        """
        return pulumi.get(self, "overdue_time")

    @overdue_time.setter
    def overdue_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "overdue_time", value)

    @property
    @pulumi.getter
    def period(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        包年包月类型VPN网关购买的时长，默认“1”。当PeriodUnit传入值为Month，Period取值范围：1~9、12、24、36。当PeriodUnit传入值为Year，Period取值范围：1～3。
        """
        return pulumi.get(self, "period")

    @period.setter
    def period(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "period", value)

    @property
    @pulumi.getter(name="periodUnit")
    def period_unit(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        包年包月类型VPN网关购买时长的单位，默认“Month”。Month：月Year：年
        """
        return pulumi.get(self, "period_unit")

    @period_unit.setter
    def period_unit(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "period_unit", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPN网关所属的项目。不填默认为default，即创建的资源属于default项目。您可调用ListProjects查询当前账号下项目的信息。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="routeCount")
    def route_count(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        VPN网关的路由条目数量。
        """
        return pulumi.get(self, "route_count")

    @route_count.setter
    def route_count(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "route_count", value)

    @property
    @pulumi.getter(name="secondaryIpAddress")
    def secondary_ip_address(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPN网关的第二个公网IP地址。仅双隧道模式的VPN网关实例返回该参数，单隧道模式的VPN网关实例不返回该参数。
        """
        return pulumi.get(self, "secondary_ip_address")

    @secondary_ip_address.setter
    def secondary_ip_address(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "secondary_ip_address", value)

    @property
    @pulumi.getter(name="secondarySubnetId")
    def secondary_subnet_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPN网关实例关联的第二个子网的ID。仅双隧道模式的VPN网关实例返回该参数，单隧道模式的VPN网关实例不返回该参数。
        """
        return pulumi.get(self, "secondary_subnet_id")

    @secondary_subnet_id.setter
    def secondary_subnet_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "secondary_subnet_id", value)

    @property
    @pulumi.getter(name="sslEnabled")
    def ssl_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启SSL VPN功能。true：开启false：关闭
        """
        return pulumi.get(self, "ssl_enabled")

    @ssl_enabled.setter
    def ssl_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "ssl_enabled", value)

    @property
    @pulumi.getter(name="sslMaxConnections")
    def ssl_max_connections(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        VPN网关的最大SSL连接数。
        """
        return pulumi.get(self, "ssl_max_connections")

    @ssl_max_connections.setter
    def ssl_max_connections(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "ssl_max_connections", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPN网关的状态。Creating: 创建中Deleting: 删除中Pending：配置中Available：可用
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPN网关使用的端口所属子网的ID。
        """
        return pulumi.get(self, "subnet_id")

    @subnet_id.setter
    def subnet_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "subnet_id", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['VpnGatewayTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['VpnGatewayTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        更新VPN网关的时间。
        """
        return pulumi.get(self, "update_time")

    @update_time.setter
    def update_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "update_time", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPN网关所在VPC的ID。
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="vpnGatewayId")
    def vpn_gateway_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPN网关的ID。
        """
        return pulumi.get(self, "vpn_gateway_id")

    @vpn_gateway_id.setter
    def vpn_gateway_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vpn_gateway_id", value)

    @property
    @pulumi.getter(name="vpnGatewayName")
    def vpn_gateway_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPN网关的名称。
        """
        return pulumi.get(self, "vpn_gateway_name")

    @vpn_gateway_name.setter
    def vpn_gateway_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vpn_gateway_name", value)


@pulumi.type_token("bytepluscc:vpn/vpnGateway:VpnGateway")
class VpnGateway(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 asn: Optional[pulumi.Input[builtins.int]] = None,
                 bandwidth: Optional[pulumi.Input[builtins.int]] = None,
                 billing_type: Optional[pulumi.Input[builtins.int]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 dual_tunnel_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 ip_stack_type: Optional[pulumi.Input[builtins.str]] = None,
                 ip_version: Optional[pulumi.Input[builtins.str]] = None,
                 ipsec_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 period: Optional[pulumi.Input[builtins.int]] = None,
                 period_unit: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 secondary_subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 ssl_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 ssl_max_connections: Optional[pulumi.Input[builtins.int]] = None,
                 subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['VpnGatewayTagArgs', 'VpnGatewayTagArgsDict']]]]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 vpn_gateway_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        当您需要通过VPN连接实现私有网络与本地数据中心或其他私有网络之间的通信，您需要先创建一个VPN网关。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        vpn_vpn_gateway_demo = bytepluscc.vpn.VpnGateway("VpnVpnGatewayDemo",
            bandwidth=5,
            billing_type=2,
            description="this is a test description",
            dual_tunnel_enabled=False,
            ip_stack_type="ipv4_only",
            ip_version="ipv4",
            vpn_gateway_name="VpnVpnGatewayDemo",
            ipsec_enabled=True,
            ssl_enabled=True,
            ssl_max_connections=5,
            project_name="default",
            vpc_id="vpc-3nr6adxxxxu8931eb64y4z2",
            subnet_id="subnet-btepcsxxxxw5h0b2u6hppyd")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:vpn/vpnGateway:VpnGateway example "vpn_gateway_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] asn: VPN网关的ASN。
        :param pulumi.Input[builtins.int] bandwidth: VPN网关的带宽规格。
        :param pulumi.Input[builtins.int] billing_type: VPN网关的计费类型。1：包年包月。2：按量计费（按固定规格）
        :param pulumi.Input[builtins.str] description: VPN网关的描述。
        :param pulumi.Input[builtins.bool] dual_tunnel_enabled: VPN网关是否开启双隧道模式。true：开启false：关闭
        :param pulumi.Input[builtins.str] ip_stack_type: VPN 网关的协议类型。ipv4*only：IPv4协议类型。ipv6*only：IPv6协议类型。ipv4_ipv6：双栈协议类型。
        :param pulumi.Input[builtins.str] ip_version: VPN网关的IP地址类型。ipv4：IPv4地址类型。ipv6：IPv6地址类型。
        :param pulumi.Input[builtins.bool] ipsec_enabled: 是否开启IPSec功能。true：开启false：关闭。
        :param pulumi.Input[builtins.int] period: 包年包月类型VPN网关购买的时长，默认“1”。当PeriodUnit传入值为Month，Period取值范围：1~9、12、24、36。当PeriodUnit传入值为Year，Period取值范围：1～3。
        :param pulumi.Input[builtins.str] period_unit: 包年包月类型VPN网关购买时长的单位，默认“Month”。Month：月Year：年
        :param pulumi.Input[builtins.str] project_name: VPN网关所属的项目。不填默认为default，即创建的资源属于default项目。您可调用ListProjects查询当前账号下项目的信息。
        :param pulumi.Input[builtins.str] secondary_subnet_id: VPN网关实例关联的第二个子网的ID。仅双隧道模式的VPN网关实例返回该参数，单隧道模式的VPN网关实例不返回该参数。
        :param pulumi.Input[builtins.bool] ssl_enabled: 是否开启SSL VPN功能。true：开启false：关闭
        :param pulumi.Input[builtins.int] ssl_max_connections: VPN网关的最大SSL连接数。
        :param pulumi.Input[builtins.str] subnet_id: VPN网关使用的端口所属子网的ID。
        :param pulumi.Input[builtins.str] vpc_id: VPN网关所在VPC的ID。
        :param pulumi.Input[builtins.str] vpn_gateway_name: VPN网关的名称。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: VpnGatewayArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        当您需要通过VPN连接实现私有网络与本地数据中心或其他私有网络之间的通信，您需要先创建一个VPN网关。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        vpn_vpn_gateway_demo = bytepluscc.vpn.VpnGateway("VpnVpnGatewayDemo",
            bandwidth=5,
            billing_type=2,
            description="this is a test description",
            dual_tunnel_enabled=False,
            ip_stack_type="ipv4_only",
            ip_version="ipv4",
            vpn_gateway_name="VpnVpnGatewayDemo",
            ipsec_enabled=True,
            ssl_enabled=True,
            ssl_max_connections=5,
            project_name="default",
            vpc_id="vpc-3nr6adxxxxu8931eb64y4z2",
            subnet_id="subnet-btepcsxxxxw5h0b2u6hppyd")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:vpn/vpnGateway:VpnGateway example "vpn_gateway_id"
        ```

        :param str resource_name: The name of the resource.
        :param VpnGatewayArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(VpnGatewayArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 asn: Optional[pulumi.Input[builtins.int]] = None,
                 bandwidth: Optional[pulumi.Input[builtins.int]] = None,
                 billing_type: Optional[pulumi.Input[builtins.int]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 dual_tunnel_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 ip_stack_type: Optional[pulumi.Input[builtins.str]] = None,
                 ip_version: Optional[pulumi.Input[builtins.str]] = None,
                 ipsec_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 period: Optional[pulumi.Input[builtins.int]] = None,
                 period_unit: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 secondary_subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 ssl_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 ssl_max_connections: Optional[pulumi.Input[builtins.int]] = None,
                 subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['VpnGatewayTagArgs', 'VpnGatewayTagArgsDict']]]]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 vpn_gateway_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = VpnGatewayArgs.__new__(VpnGatewayArgs)

            __props__.__dict__["asn"] = asn
            if bandwidth is None and not opts.urn:
                raise TypeError("Missing required property 'bandwidth'")
            __props__.__dict__["bandwidth"] = bandwidth
            __props__.__dict__["billing_type"] = billing_type
            __props__.__dict__["description"] = description
            __props__.__dict__["dual_tunnel_enabled"] = dual_tunnel_enabled
            __props__.__dict__["ip_stack_type"] = ip_stack_type
            __props__.__dict__["ip_version"] = ip_version
            __props__.__dict__["ipsec_enabled"] = ipsec_enabled
            __props__.__dict__["period"] = period
            __props__.__dict__["period_unit"] = period_unit
            __props__.__dict__["project_name"] = project_name
            __props__.__dict__["secondary_subnet_id"] = secondary_subnet_id
            __props__.__dict__["ssl_enabled"] = ssl_enabled
            __props__.__dict__["ssl_max_connections"] = ssl_max_connections
            if subnet_id is None and not opts.urn:
                raise TypeError("Missing required property 'subnet_id'")
            __props__.__dict__["subnet_id"] = subnet_id
            __props__.__dict__["tags"] = tags
            if vpc_id is None and not opts.urn:
                raise TypeError("Missing required property 'vpc_id'")
            __props__.__dict__["vpc_id"] = vpc_id
            __props__.__dict__["vpn_gateway_name"] = vpn_gateway_name
            __props__.__dict__["business_status"] = None
            __props__.__dict__["connection_count"] = None
            __props__.__dict__["create_time"] = None
            __props__.__dict__["deleted_time"] = None
            __props__.__dict__["expired_time"] = None
            __props__.__dict__["ip_address"] = None
            __props__.__dict__["is_blocked"] = None
            __props__.__dict__["lock_reason"] = None
            __props__.__dict__["overdue_time"] = None
            __props__.__dict__["route_count"] = None
            __props__.__dict__["secondary_ip_address"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["update_time"] = None
            __props__.__dict__["vpn_gateway_id"] = None
        super(VpnGateway, __self__).__init__(
            'bytepluscc:vpn/vpnGateway:VpnGateway',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            asn: Optional[pulumi.Input[builtins.int]] = None,
            bandwidth: Optional[pulumi.Input[builtins.int]] = None,
            billing_type: Optional[pulumi.Input[builtins.int]] = None,
            business_status: Optional[pulumi.Input[builtins.str]] = None,
            connection_count: Optional[pulumi.Input[builtins.int]] = None,
            create_time: Optional[pulumi.Input[builtins.str]] = None,
            deleted_time: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            dual_tunnel_enabled: Optional[pulumi.Input[builtins.bool]] = None,
            expired_time: Optional[pulumi.Input[builtins.str]] = None,
            ip_address: Optional[pulumi.Input[builtins.str]] = None,
            ip_stack_type: Optional[pulumi.Input[builtins.str]] = None,
            ip_version: Optional[pulumi.Input[builtins.str]] = None,
            ipsec_enabled: Optional[pulumi.Input[builtins.bool]] = None,
            is_blocked: Optional[pulumi.Input[builtins.bool]] = None,
            lock_reason: Optional[pulumi.Input[builtins.str]] = None,
            overdue_time: Optional[pulumi.Input[builtins.str]] = None,
            period: Optional[pulumi.Input[builtins.int]] = None,
            period_unit: Optional[pulumi.Input[builtins.str]] = None,
            project_name: Optional[pulumi.Input[builtins.str]] = None,
            route_count: Optional[pulumi.Input[builtins.int]] = None,
            secondary_ip_address: Optional[pulumi.Input[builtins.str]] = None,
            secondary_subnet_id: Optional[pulumi.Input[builtins.str]] = None,
            ssl_enabled: Optional[pulumi.Input[builtins.bool]] = None,
            ssl_max_connections: Optional[pulumi.Input[builtins.int]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            subnet_id: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['VpnGatewayTagArgs', 'VpnGatewayTagArgsDict']]]]] = None,
            update_time: Optional[pulumi.Input[builtins.str]] = None,
            vpc_id: Optional[pulumi.Input[builtins.str]] = None,
            vpn_gateway_id: Optional[pulumi.Input[builtins.str]] = None,
            vpn_gateway_name: Optional[pulumi.Input[builtins.str]] = None) -> 'VpnGateway':
        """
        Get an existing VpnGateway resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] asn: VPN网关的ASN。
        :param pulumi.Input[builtins.int] bandwidth: VPN网关的带宽规格。
        :param pulumi.Input[builtins.int] billing_type: VPN网关的计费类型。1：包年包月。2：按量计费（按固定规格）
        :param pulumi.Input[builtins.str] business_status: VPN网关的计费状态。Normal: 正常。FinancialLocked: 被锁定。
        :param pulumi.Input[builtins.int] connection_count: VPN网关关联IPsec连接的数量。
        :param pulumi.Input[builtins.str] create_time: 创建VPN网关的时间。
        :param pulumi.Input[builtins.str] deleted_time: 预期资源强制回收时间。
        :param pulumi.Input[builtins.str] description: VPN网关的描述。
        :param pulumi.Input[builtins.bool] dual_tunnel_enabled: VPN网关是否开启双隧道模式。true：开启false：关闭
        :param pulumi.Input[builtins.str] expired_time: VPN网关的到期时间。
        :param pulumi.Input[builtins.str] ip_address: VPN网关的公网IP地址。
        :param pulumi.Input[builtins.str] ip_stack_type: VPN 网关的协议类型。ipv4*only：IPv4协议类型。ipv6*only：IPv6协议类型。ipv4_ipv6：双栈协议类型。
        :param pulumi.Input[builtins.str] ip_version: VPN网关的IP地址类型。ipv4：IPv4地址类型。ipv6：IPv6地址类型。
        :param pulumi.Input[builtins.bool] ipsec_enabled: 是否开启IPSec功能。true：开启false：关闭。
        :param pulumi.Input[builtins.bool] is_blocked: 当前资源的状态是否被封禁。true：封禁false：未封禁。
        :param pulumi.Input[builtins.str] lock_reason: VPN网关的锁定原因。financial：因欠费被锁定。security：因安全被锁定。unlock：未锁定。
        :param pulumi.Input[builtins.str] overdue_time: 资源冻结时间。仅当资源因为欠费冻结，此参数才会有返回值，否则均返回空值。
        :param pulumi.Input[builtins.int] period: 包年包月类型VPN网关购买的时长，默认“1”。当PeriodUnit传入值为Month，Period取值范围：1~9、12、24、36。当PeriodUnit传入值为Year，Period取值范围：1～3。
        :param pulumi.Input[builtins.str] period_unit: 包年包月类型VPN网关购买时长的单位，默认“Month”。Month：月Year：年
        :param pulumi.Input[builtins.str] project_name: VPN网关所属的项目。不填默认为default，即创建的资源属于default项目。您可调用ListProjects查询当前账号下项目的信息。
        :param pulumi.Input[builtins.int] route_count: VPN网关的路由条目数量。
        :param pulumi.Input[builtins.str] secondary_ip_address: VPN网关的第二个公网IP地址。仅双隧道模式的VPN网关实例返回该参数，单隧道模式的VPN网关实例不返回该参数。
        :param pulumi.Input[builtins.str] secondary_subnet_id: VPN网关实例关联的第二个子网的ID。仅双隧道模式的VPN网关实例返回该参数，单隧道模式的VPN网关实例不返回该参数。
        :param pulumi.Input[builtins.bool] ssl_enabled: 是否开启SSL VPN功能。true：开启false：关闭
        :param pulumi.Input[builtins.int] ssl_max_connections: VPN网关的最大SSL连接数。
        :param pulumi.Input[builtins.str] status: VPN网关的状态。Creating: 创建中Deleting: 删除中Pending：配置中Available：可用
        :param pulumi.Input[builtins.str] subnet_id: VPN网关使用的端口所属子网的ID。
        :param pulumi.Input[builtins.str] update_time: 更新VPN网关的时间。
        :param pulumi.Input[builtins.str] vpc_id: VPN网关所在VPC的ID。
        :param pulumi.Input[builtins.str] vpn_gateway_id: VPN网关的ID。
        :param pulumi.Input[builtins.str] vpn_gateway_name: VPN网关的名称。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _VpnGatewayState.__new__(_VpnGatewayState)

        __props__.__dict__["asn"] = asn
        __props__.__dict__["bandwidth"] = bandwidth
        __props__.__dict__["billing_type"] = billing_type
        __props__.__dict__["business_status"] = business_status
        __props__.__dict__["connection_count"] = connection_count
        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["deleted_time"] = deleted_time
        __props__.__dict__["description"] = description
        __props__.__dict__["dual_tunnel_enabled"] = dual_tunnel_enabled
        __props__.__dict__["expired_time"] = expired_time
        __props__.__dict__["ip_address"] = ip_address
        __props__.__dict__["ip_stack_type"] = ip_stack_type
        __props__.__dict__["ip_version"] = ip_version
        __props__.__dict__["ipsec_enabled"] = ipsec_enabled
        __props__.__dict__["is_blocked"] = is_blocked
        __props__.__dict__["lock_reason"] = lock_reason
        __props__.__dict__["overdue_time"] = overdue_time
        __props__.__dict__["period"] = period
        __props__.__dict__["period_unit"] = period_unit
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["route_count"] = route_count
        __props__.__dict__["secondary_ip_address"] = secondary_ip_address
        __props__.__dict__["secondary_subnet_id"] = secondary_subnet_id
        __props__.__dict__["ssl_enabled"] = ssl_enabled
        __props__.__dict__["ssl_max_connections"] = ssl_max_connections
        __props__.__dict__["status"] = status
        __props__.__dict__["subnet_id"] = subnet_id
        __props__.__dict__["tags"] = tags
        __props__.__dict__["update_time"] = update_time
        __props__.__dict__["vpc_id"] = vpc_id
        __props__.__dict__["vpn_gateway_id"] = vpn_gateway_id
        __props__.__dict__["vpn_gateway_name"] = vpn_gateway_name
        return VpnGateway(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def asn(self) -> pulumi.Output[builtins.int]:
        """
        VPN网关的ASN。
        """
        return pulumi.get(self, "asn")

    @property
    @pulumi.getter
    def bandwidth(self) -> pulumi.Output[builtins.int]:
        """
        VPN网关的带宽规格。
        """
        return pulumi.get(self, "bandwidth")

    @property
    @pulumi.getter(name="billingType")
    def billing_type(self) -> pulumi.Output[builtins.int]:
        """
        VPN网关的计费类型。1：包年包月。2：按量计费（按固定规格）
        """
        return pulumi.get(self, "billing_type")

    @property
    @pulumi.getter(name="businessStatus")
    def business_status(self) -> pulumi.Output[builtins.str]:
        """
        VPN网关的计费状态。Normal: 正常。FinancialLocked: 被锁定。
        """
        return pulumi.get(self, "business_status")

    @property
    @pulumi.getter(name="connectionCount")
    def connection_count(self) -> pulumi.Output[builtins.int]:
        """
        VPN网关关联IPsec连接的数量。
        """
        return pulumi.get(self, "connection_count")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[builtins.str]:
        """
        创建VPN网关的时间。
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="deletedTime")
    def deleted_time(self) -> pulumi.Output[builtins.str]:
        """
        预期资源强制回收时间。
        """
        return pulumi.get(self, "deleted_time")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        VPN网关的描述。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="dualTunnelEnabled")
    def dual_tunnel_enabled(self) -> pulumi.Output[builtins.bool]:
        """
        VPN网关是否开启双隧道模式。true：开启false：关闭
        """
        return pulumi.get(self, "dual_tunnel_enabled")

    @property
    @pulumi.getter(name="expiredTime")
    def expired_time(self) -> pulumi.Output[builtins.str]:
        """
        VPN网关的到期时间。
        """
        return pulumi.get(self, "expired_time")

    @property
    @pulumi.getter(name="ipAddress")
    def ip_address(self) -> pulumi.Output[builtins.str]:
        """
        VPN网关的公网IP地址。
        """
        return pulumi.get(self, "ip_address")

    @property
    @pulumi.getter(name="ipStackType")
    def ip_stack_type(self) -> pulumi.Output[builtins.str]:
        """
        VPN 网关的协议类型。ipv4*only：IPv4协议类型。ipv6*only：IPv6协议类型。ipv4_ipv6：双栈协议类型。
        """
        return pulumi.get(self, "ip_stack_type")

    @property
    @pulumi.getter(name="ipVersion")
    def ip_version(self) -> pulumi.Output[builtins.str]:
        """
        VPN网关的IP地址类型。ipv4：IPv4地址类型。ipv6：IPv6地址类型。
        """
        return pulumi.get(self, "ip_version")

    @property
    @pulumi.getter(name="ipsecEnabled")
    def ipsec_enabled(self) -> pulumi.Output[builtins.bool]:
        """
        是否开启IPSec功能。true：开启false：关闭。
        """
        return pulumi.get(self, "ipsec_enabled")

    @property
    @pulumi.getter(name="isBlocked")
    def is_blocked(self) -> pulumi.Output[builtins.bool]:
        """
        当前资源的状态是否被封禁。true：封禁false：未封禁。
        """
        return pulumi.get(self, "is_blocked")

    @property
    @pulumi.getter(name="lockReason")
    def lock_reason(self) -> pulumi.Output[builtins.str]:
        """
        VPN网关的锁定原因。financial：因欠费被锁定。security：因安全被锁定。unlock：未锁定。
        """
        return pulumi.get(self, "lock_reason")

    @property
    @pulumi.getter(name="overdueTime")
    def overdue_time(self) -> pulumi.Output[builtins.str]:
        """
        资源冻结时间。仅当资源因为欠费冻结，此参数才会有返回值，否则均返回空值。
        """
        return pulumi.get(self, "overdue_time")

    @property
    @pulumi.getter
    def period(self) -> pulumi.Output[builtins.int]:
        """
        包年包月类型VPN网关购买的时长，默认“1”。当PeriodUnit传入值为Month，Period取值范围：1~9、12、24、36。当PeriodUnit传入值为Year，Period取值范围：1～3。
        """
        return pulumi.get(self, "period")

    @property
    @pulumi.getter(name="periodUnit")
    def period_unit(self) -> pulumi.Output[builtins.str]:
        """
        包年包月类型VPN网关购买时长的单位，默认“Month”。Month：月Year：年
        """
        return pulumi.get(self, "period_unit")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[builtins.str]:
        """
        VPN网关所属的项目。不填默认为default，即创建的资源属于default项目。您可调用ListProjects查询当前账号下项目的信息。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="routeCount")
    def route_count(self) -> pulumi.Output[builtins.int]:
        """
        VPN网关的路由条目数量。
        """
        return pulumi.get(self, "route_count")

    @property
    @pulumi.getter(name="secondaryIpAddress")
    def secondary_ip_address(self) -> pulumi.Output[builtins.str]:
        """
        VPN网关的第二个公网IP地址。仅双隧道模式的VPN网关实例返回该参数，单隧道模式的VPN网关实例不返回该参数。
        """
        return pulumi.get(self, "secondary_ip_address")

    @property
    @pulumi.getter(name="secondarySubnetId")
    def secondary_subnet_id(self) -> pulumi.Output[builtins.str]:
        """
        VPN网关实例关联的第二个子网的ID。仅双隧道模式的VPN网关实例返回该参数，单隧道模式的VPN网关实例不返回该参数。
        """
        return pulumi.get(self, "secondary_subnet_id")

    @property
    @pulumi.getter(name="sslEnabled")
    def ssl_enabled(self) -> pulumi.Output[builtins.bool]:
        """
        是否开启SSL VPN功能。true：开启false：关闭
        """
        return pulumi.get(self, "ssl_enabled")

    @property
    @pulumi.getter(name="sslMaxConnections")
    def ssl_max_connections(self) -> pulumi.Output[builtins.int]:
        """
        VPN网关的最大SSL连接数。
        """
        return pulumi.get(self, "ssl_max_connections")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        VPN网关的状态。Creating: 创建中Deleting: 删除中Pending：配置中Available：可用
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> pulumi.Output[builtins.str]:
        """
        VPN网关使用的端口所属子网的ID。
        """
        return pulumi.get(self, "subnet_id")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.VpnGatewayTag']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> pulumi.Output[builtins.str]:
        """
        更新VPN网关的时间。
        """
        return pulumi.get(self, "update_time")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Output[builtins.str]:
        """
        VPN网关所在VPC的ID。
        """
        return pulumi.get(self, "vpc_id")

    @property
    @pulumi.getter(name="vpnGatewayId")
    def vpn_gateway_id(self) -> pulumi.Output[builtins.str]:
        """
        VPN网关的ID。
        """
        return pulumi.get(self, "vpn_gateway_id")

    @property
    @pulumi.getter(name="vpnGatewayName")
    def vpn_gateway_name(self) -> pulumi.Output[builtins.str]:
        """
        VPN网关的名称。
        """
        return pulumi.get(self, "vpn_gateway_name")

