# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetGroupResult',
    'AwaitableGetGroupResult',
    'get_group',
    'get_group_output',
]

@pulumi.output_type
class GetGroupResult:
    """
    A collection of values returned by getGroup.
    """
    def __init__(__self__, created_time=None, description=None, group_id=None, group_name=None, id=None, instance_id=None, owner_id=None, owner_name=None, reset_info=None, status=None, topic_infos=None):
        if created_time and not isinstance(created_time, str):
            raise TypeError("Expected argument 'created_time' to be a str")
        pulumi.set(__self__, "created_time", created_time)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if group_id and not isinstance(group_id, str):
            raise TypeError("Expected argument 'group_id' to be a str")
        pulumi.set(__self__, "group_id", group_id)
        if group_name and not isinstance(group_name, str):
            raise TypeError("Expected argument 'group_name' to be a str")
        pulumi.set(__self__, "group_name", group_name)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if instance_id and not isinstance(instance_id, str):
            raise TypeError("Expected argument 'instance_id' to be a str")
        pulumi.set(__self__, "instance_id", instance_id)
        if owner_id and not isinstance(owner_id, str):
            raise TypeError("Expected argument 'owner_id' to be a str")
        pulumi.set(__self__, "owner_id", owner_id)
        if owner_name and not isinstance(owner_name, str):
            raise TypeError("Expected argument 'owner_name' to be a str")
        pulumi.set(__self__, "owner_name", owner_name)
        if reset_info and not isinstance(reset_info, dict):
            raise TypeError("Expected argument 'reset_info' to be a dict")
        pulumi.set(__self__, "reset_info", reset_info)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if topic_infos and not isinstance(topic_infos, list):
            raise TypeError("Expected argument 'topic_infos' to be a list")
        pulumi.set(__self__, "topic_infos", topic_infos)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> builtins.str:
        """
        Consumer Group 创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        Consumer Group 描述。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> builtins.str:
        """
        Consumer Group 的 ID。
        """
        return pulumi.get(self, "group_id")

    @property
    @pulumi.getter(name="groupName")
    def group_name(self) -> builtins.str:
        """
        自定义设置Consumer Group 的名称，约束限制如下：只能由小写英文字符、数字、下划线和中划线（-）组成。长度为 3~64 字符。
        """
        return pulumi.get(self, "group_name")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> builtins.str:
        """
        所属 BMQ 实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="ownerId")
    def owner_id(self) -> builtins.str:
        """
        Consumer Group 所属用户的 ID。
        """
        return pulumi.get(self, "owner_id")

    @property
    @pulumi.getter(name="ownerName")
    def owner_name(self) -> builtins.str:
        """
        Consumer Group 所属用户的名称。
        """
        return pulumi.get(self, "owner_name")

    @property
    @pulumi.getter(name="resetInfo")
    def reset_info(self) -> 'outputs.GetGroupResetInfoResult':
        """
        重置消费位点信息。
        """
        return pulumi.get(self, "reset_info")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        Consumer Group 的状态。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="topicInfos")
    def topic_infos(self) -> Sequence['outputs.GetGroupTopicInfoResult']:
        """
        Topic 列表。
        """
        return pulumi.get(self, "topic_infos")


class AwaitableGetGroupResult(GetGroupResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetGroupResult(
            created_time=self.created_time,
            description=self.description,
            group_id=self.group_id,
            group_name=self.group_name,
            id=self.id,
            instance_id=self.instance_id,
            owner_id=self.owner_id,
            owner_name=self.owner_name,
            reset_info=self.reset_info,
            status=self.status,
            topic_infos=self.topic_infos)


def get_group(id: Optional[builtins.str] = None,
              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetGroupResult:
    """
    Data Source schema for Byteplus::BMQ::Group


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:bmq/getGroup:getGroup', __args__, opts=opts, typ=GetGroupResult).value

    return AwaitableGetGroupResult(
        created_time=pulumi.get(__ret__, 'created_time'),
        description=pulumi.get(__ret__, 'description'),
        group_id=pulumi.get(__ret__, 'group_id'),
        group_name=pulumi.get(__ret__, 'group_name'),
        id=pulumi.get(__ret__, 'id'),
        instance_id=pulumi.get(__ret__, 'instance_id'),
        owner_id=pulumi.get(__ret__, 'owner_id'),
        owner_name=pulumi.get(__ret__, 'owner_name'),
        reset_info=pulumi.get(__ret__, 'reset_info'),
        status=pulumi.get(__ret__, 'status'),
        topic_infos=pulumi.get(__ret__, 'topic_infos'))
def get_group_output(id: Optional[pulumi.Input[builtins.str]] = None,
                     opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetGroupResult]:
    """
    Data Source schema for Byteplus::BMQ::Group


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:bmq/getGroup:getGroup', __args__, opts=opts, typ=GetGroupResult)
    return __ret__.apply(lambda __response__: GetGroupResult(
        created_time=pulumi.get(__response__, 'created_time'),
        description=pulumi.get(__response__, 'description'),
        group_id=pulumi.get(__response__, 'group_id'),
        group_name=pulumi.get(__response__, 'group_name'),
        id=pulumi.get(__response__, 'id'),
        instance_id=pulumi.get(__response__, 'instance_id'),
        owner_id=pulumi.get(__response__, 'owner_id'),
        owner_name=pulumi.get(__response__, 'owner_name'),
        reset_info=pulumi.get(__response__, 'reset_info'),
        status=pulumi.get(__response__, 'status'),
        topic_infos=pulumi.get(__response__, 'topic_infos')))
