# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['WorkspaceArgs', 'Workspace']

@pulumi.input_type
class WorkspaceArgs:
    def __init__(__self__, *,
                 instance_type_id: pulumi.Input[builtins.str],
                 name: pulumi.Input[builtins.str],
                 delete_protection_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 password: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['WorkspaceTagArgs']]]] = None,
                 username: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a Workspace resource.
        :param pulumi.Input[builtins.str] instance_type_id: 工作区规格,vmp.standard.15d：15 天存储时长工作区。vmp.standard.30d：30 天存储时长工作区。vmp.standard.90d：90 天存储时长工作区。vmp.standard.180d：180 天存储时长工作区。vmp.standard.1y：1 年存储时长工作区。
        :param pulumi.Input[builtins.str] name: 工作区名称，字符串形式，长度限制为 1～100。
        :param pulumi.Input[builtins.bool] delete_protection_enabled: 是否开启工作区删除保护,true：开启，false：关闭。
        :param pulumi.Input[builtins.str] description: 工作区描述信息，字符串形式，长度限制为 0～200。
        :param pulumi.Input[builtins.str] password: 工作区 BasicAuth 密码。
        :param pulumi.Input[builtins.str] project_name: 项目名称。
        :param pulumi.Input[builtins.str] username: 工作区 BasicAuth 用户名。
        """
        pulumi.set(__self__, "instance_type_id", instance_type_id)
        pulumi.set(__self__, "name", name)
        if delete_protection_enabled is not None:
            pulumi.set(__self__, "delete_protection_enabled", delete_protection_enabled)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if username is not None:
            pulumi.set(__self__, "username", username)

    @property
    @pulumi.getter(name="instanceTypeId")
    def instance_type_id(self) -> pulumi.Input[builtins.str]:
        """
        工作区规格,vmp.standard.15d：15 天存储时长工作区。vmp.standard.30d：30 天存储时长工作区。vmp.standard.90d：90 天存储时长工作区。vmp.standard.180d：180 天存储时长工作区。vmp.standard.1y：1 年存储时长工作区。
        """
        return pulumi.get(self, "instance_type_id")

    @instance_type_id.setter
    def instance_type_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "instance_type_id", value)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[builtins.str]:
        """
        工作区名称，字符串形式，长度限制为 1～100。
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="deleteProtectionEnabled")
    def delete_protection_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启工作区删除保护,true：开启，false：关闭。
        """
        return pulumi.get(self, "delete_protection_enabled")

    @delete_protection_enabled.setter
    def delete_protection_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "delete_protection_enabled", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        工作区描述信息，字符串形式，长度限制为 0～200。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        工作区 BasicAuth 密码。
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        项目名称。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['WorkspaceTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['WorkspaceTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter
    def username(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        工作区 BasicAuth 用户名。
        """
        return pulumi.get(self, "username")

    @username.setter
    def username(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "username", value)


@pulumi.input_type
class _WorkspaceState:
    def __init__(__self__, *,
                 create_time: Optional[pulumi.Input[builtins.str]] = None,
                 delete_protection_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 instance_type: Optional[pulumi.Input['WorkspaceInstanceTypeArgs']] = None,
                 instance_type_id: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 overdue_reclaim_time: Optional[pulumi.Input[builtins.str]] = None,
                 password: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 prometheus_push_intranet_endpoint: Optional[pulumi.Input[builtins.str]] = None,
                 prometheus_query_intranet_endpoint: Optional[pulumi.Input[builtins.str]] = None,
                 prometheus_write_intranet_endpoint: Optional[pulumi.Input[builtins.str]] = None,
                 quota: Optional[pulumi.Input['WorkspaceQuotaArgs']] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['WorkspaceTagArgs']]]] = None,
                 usage: Optional[pulumi.Input['WorkspaceUsageArgs']] = None,
                 username: Optional[pulumi.Input[builtins.str]] = None,
                 workspace_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Workspace resources.
        :param pulumi.Input[builtins.str] create_time: 工作区创建时间，RFC3339 格式。
        :param pulumi.Input[builtins.bool] delete_protection_enabled: 是否开启工作区删除保护,true：开启，false：关闭。
        :param pulumi.Input[builtins.str] description: 工作区描述信息，字符串形式，长度限制为 0～200。
        :param pulumi.Input['WorkspaceInstanceTypeArgs'] instance_type: 工作区规格详情。
        :param pulumi.Input[builtins.str] instance_type_id: 工作区规格,vmp.standard.15d：15 天存储时长工作区。vmp.standard.30d：30 天存储时长工作区。vmp.standard.90d：90 天存储时长工作区。vmp.standard.180d：180 天存储时长工作区。vmp.standard.1y：1 年存储时长工作区。
        :param pulumi.Input[builtins.str] name: 工作区名称，字符串形式，长度限制为 1～100。
        :param pulumi.Input[builtins.str] overdue_reclaim_time: 工作区预期欠费回收时间，RFC3339 格式。
        :param pulumi.Input[builtins.str] password: 工作区 BasicAuth 密码。
        :param pulumi.Input[builtins.str] project_name: 项目名称。
        :param pulumi.Input[builtins.str] prometheus_push_intranet_endpoint: 工作区 Push Gateway URL 地址。
        :param pulumi.Input[builtins.str] prometheus_query_intranet_endpoint: 工作区 Query URL 地址。
        :param pulumi.Input[builtins.str] prometheus_write_intranet_endpoint: 工作区 RemoteWrite URL 地址。
        :param pulumi.Input['WorkspaceQuotaArgs'] quota: 工作区配额详情。
        :param pulumi.Input[builtins.str] status: 工作区状态，取值：Creating：创建中 Active：正常 Updating：更新中 Deleting：删除中 OverdueShutted：欠费关停 Resuming：恢复中 Error：错误。
        :param pulumi.Input['WorkspaceUsageArgs'] usage: 工作区用量。
        :param pulumi.Input[builtins.str] username: 工作区 BasicAuth 用户名。
        :param pulumi.Input[builtins.str] workspace_id: 工作区Id。
        """
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if delete_protection_enabled is not None:
            pulumi.set(__self__, "delete_protection_enabled", delete_protection_enabled)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if instance_type is not None:
            pulumi.set(__self__, "instance_type", instance_type)
        if instance_type_id is not None:
            pulumi.set(__self__, "instance_type_id", instance_type_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if overdue_reclaim_time is not None:
            pulumi.set(__self__, "overdue_reclaim_time", overdue_reclaim_time)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if prometheus_push_intranet_endpoint is not None:
            pulumi.set(__self__, "prometheus_push_intranet_endpoint", prometheus_push_intranet_endpoint)
        if prometheus_query_intranet_endpoint is not None:
            pulumi.set(__self__, "prometheus_query_intranet_endpoint", prometheus_query_intranet_endpoint)
        if prometheus_write_intranet_endpoint is not None:
            pulumi.set(__self__, "prometheus_write_intranet_endpoint", prometheus_write_intranet_endpoint)
        if quota is not None:
            pulumi.set(__self__, "quota", quota)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if usage is not None:
            pulumi.set(__self__, "usage", usage)
        if username is not None:
            pulumi.set(__self__, "username", username)
        if workspace_id is not None:
            pulumi.set(__self__, "workspace_id", workspace_id)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        工作区创建时间，RFC3339 格式。
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="deleteProtectionEnabled")
    def delete_protection_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启工作区删除保护,true：开启，false：关闭。
        """
        return pulumi.get(self, "delete_protection_enabled")

    @delete_protection_enabled.setter
    def delete_protection_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "delete_protection_enabled", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        工作区描述信息，字符串形式，长度限制为 0～200。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> Optional[pulumi.Input['WorkspaceInstanceTypeArgs']]:
        """
        工作区规格详情。
        """
        return pulumi.get(self, "instance_type")

    @instance_type.setter
    def instance_type(self, value: Optional[pulumi.Input['WorkspaceInstanceTypeArgs']]):
        pulumi.set(self, "instance_type", value)

    @property
    @pulumi.getter(name="instanceTypeId")
    def instance_type_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        工作区规格,vmp.standard.15d：15 天存储时长工作区。vmp.standard.30d：30 天存储时长工作区。vmp.standard.90d：90 天存储时长工作区。vmp.standard.180d：180 天存储时长工作区。vmp.standard.1y：1 年存储时长工作区。
        """
        return pulumi.get(self, "instance_type_id")

    @instance_type_id.setter
    def instance_type_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_type_id", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        工作区名称，字符串形式，长度限制为 1～100。
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="overdueReclaimTime")
    def overdue_reclaim_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        工作区预期欠费回收时间，RFC3339 格式。
        """
        return pulumi.get(self, "overdue_reclaim_time")

    @overdue_reclaim_time.setter
    def overdue_reclaim_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "overdue_reclaim_time", value)

    @property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        工作区 BasicAuth 密码。
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        项目名称。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="prometheusPushIntranetEndpoint")
    def prometheus_push_intranet_endpoint(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        工作区 Push Gateway URL 地址。
        """
        return pulumi.get(self, "prometheus_push_intranet_endpoint")

    @prometheus_push_intranet_endpoint.setter
    def prometheus_push_intranet_endpoint(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "prometheus_push_intranet_endpoint", value)

    @property
    @pulumi.getter(name="prometheusQueryIntranetEndpoint")
    def prometheus_query_intranet_endpoint(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        工作区 Query URL 地址。
        """
        return pulumi.get(self, "prometheus_query_intranet_endpoint")

    @prometheus_query_intranet_endpoint.setter
    def prometheus_query_intranet_endpoint(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "prometheus_query_intranet_endpoint", value)

    @property
    @pulumi.getter(name="prometheusWriteIntranetEndpoint")
    def prometheus_write_intranet_endpoint(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        工作区 RemoteWrite URL 地址。
        """
        return pulumi.get(self, "prometheus_write_intranet_endpoint")

    @prometheus_write_intranet_endpoint.setter
    def prometheus_write_intranet_endpoint(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "prometheus_write_intranet_endpoint", value)

    @property
    @pulumi.getter
    def quota(self) -> Optional[pulumi.Input['WorkspaceQuotaArgs']]:
        """
        工作区配额详情。
        """
        return pulumi.get(self, "quota")

    @quota.setter
    def quota(self, value: Optional[pulumi.Input['WorkspaceQuotaArgs']]):
        pulumi.set(self, "quota", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        工作区状态，取值：Creating：创建中 Active：正常 Updating：更新中 Deleting：删除中 OverdueShutted：欠费关停 Resuming：恢复中 Error：错误。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['WorkspaceTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['WorkspaceTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter
    def usage(self) -> Optional[pulumi.Input['WorkspaceUsageArgs']]:
        """
        工作区用量。
        """
        return pulumi.get(self, "usage")

    @usage.setter
    def usage(self, value: Optional[pulumi.Input['WorkspaceUsageArgs']]):
        pulumi.set(self, "usage", value)

    @property
    @pulumi.getter
    def username(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        工作区 BasicAuth 用户名。
        """
        return pulumi.get(self, "username")

    @username.setter
    def username(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "username", value)

    @property
    @pulumi.getter(name="workspaceId")
    def workspace_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        工作区Id。
        """
        return pulumi.get(self, "workspace_id")

    @workspace_id.setter
    def workspace_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "workspace_id", value)


@pulumi.type_token("bytepluscc:vmp/workspace:Workspace")
class Workspace(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 delete_protection_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 instance_type_id: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 password: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['WorkspaceTagArgs', 'WorkspaceTagArgsDict']]]]] = None,
                 username: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        工作区（Workspace）是 VMP 服务中采集数据和规则的抽象整合，为用户提供物理隔离或逻辑隔离的 Prometheus 能力。在 VMP 服务中可创建不同的工作区，不同工作区中的数据彼此隔离。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        workspace_demo = bytepluscc.vmp.Workspace("WorkspaceDemo",
            username="WorkspaceDemo",
            password="***********",
            name="WorkspaceDemo",
            description="WorkspaceDemo",
            delete_protection_enabled=False,
            instance_type_id="vmp.standard.xxx",
            project_name="default",
            tags=[{
                "key": "env",
                "value": "test",
            }])
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:vmp/workspace:Workspace example "workspace_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.bool] delete_protection_enabled: 是否开启工作区删除保护,true：开启，false：关闭。
        :param pulumi.Input[builtins.str] description: 工作区描述信息，字符串形式，长度限制为 0～200。
        :param pulumi.Input[builtins.str] instance_type_id: 工作区规格,vmp.standard.15d：15 天存储时长工作区。vmp.standard.30d：30 天存储时长工作区。vmp.standard.90d：90 天存储时长工作区。vmp.standard.180d：180 天存储时长工作区。vmp.standard.1y：1 年存储时长工作区。
        :param pulumi.Input[builtins.str] name: 工作区名称，字符串形式，长度限制为 1～100。
        :param pulumi.Input[builtins.str] password: 工作区 BasicAuth 密码。
        :param pulumi.Input[builtins.str] project_name: 项目名称。
        :param pulumi.Input[builtins.str] username: 工作区 BasicAuth 用户名。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: WorkspaceArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        工作区（Workspace）是 VMP 服务中采集数据和规则的抽象整合，为用户提供物理隔离或逻辑隔离的 Prometheus 能力。在 VMP 服务中可创建不同的工作区，不同工作区中的数据彼此隔离。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        workspace_demo = bytepluscc.vmp.Workspace("WorkspaceDemo",
            username="WorkspaceDemo",
            password="***********",
            name="WorkspaceDemo",
            description="WorkspaceDemo",
            delete_protection_enabled=False,
            instance_type_id="vmp.standard.xxx",
            project_name="default",
            tags=[{
                "key": "env",
                "value": "test",
            }])
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:vmp/workspace:Workspace example "workspace_id"
        ```

        :param str resource_name: The name of the resource.
        :param WorkspaceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(WorkspaceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 delete_protection_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 instance_type_id: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 password: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['WorkspaceTagArgs', 'WorkspaceTagArgsDict']]]]] = None,
                 username: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = WorkspaceArgs.__new__(WorkspaceArgs)

            __props__.__dict__["delete_protection_enabled"] = delete_protection_enabled
            __props__.__dict__["description"] = description
            if instance_type_id is None and not opts.urn:
                raise TypeError("Missing required property 'instance_type_id'")
            __props__.__dict__["instance_type_id"] = instance_type_id
            if name is None and not opts.urn:
                raise TypeError("Missing required property 'name'")
            __props__.__dict__["name"] = name
            __props__.__dict__["password"] = password
            __props__.__dict__["project_name"] = project_name
            __props__.__dict__["tags"] = tags
            __props__.__dict__["username"] = username
            __props__.__dict__["create_time"] = None
            __props__.__dict__["instance_type"] = None
            __props__.__dict__["overdue_reclaim_time"] = None
            __props__.__dict__["prometheus_push_intranet_endpoint"] = None
            __props__.__dict__["prometheus_query_intranet_endpoint"] = None
            __props__.__dict__["prometheus_write_intranet_endpoint"] = None
            __props__.__dict__["quota"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["usage"] = None
            __props__.__dict__["workspace_id"] = None
        super(Workspace, __self__).__init__(
            'bytepluscc:vmp/workspace:Workspace',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            create_time: Optional[pulumi.Input[builtins.str]] = None,
            delete_protection_enabled: Optional[pulumi.Input[builtins.bool]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            instance_type: Optional[pulumi.Input[Union['WorkspaceInstanceTypeArgs', 'WorkspaceInstanceTypeArgsDict']]] = None,
            instance_type_id: Optional[pulumi.Input[builtins.str]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            overdue_reclaim_time: Optional[pulumi.Input[builtins.str]] = None,
            password: Optional[pulumi.Input[builtins.str]] = None,
            project_name: Optional[pulumi.Input[builtins.str]] = None,
            prometheus_push_intranet_endpoint: Optional[pulumi.Input[builtins.str]] = None,
            prometheus_query_intranet_endpoint: Optional[pulumi.Input[builtins.str]] = None,
            prometheus_write_intranet_endpoint: Optional[pulumi.Input[builtins.str]] = None,
            quota: Optional[pulumi.Input[Union['WorkspaceQuotaArgs', 'WorkspaceQuotaArgsDict']]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['WorkspaceTagArgs', 'WorkspaceTagArgsDict']]]]] = None,
            usage: Optional[pulumi.Input[Union['WorkspaceUsageArgs', 'WorkspaceUsageArgsDict']]] = None,
            username: Optional[pulumi.Input[builtins.str]] = None,
            workspace_id: Optional[pulumi.Input[builtins.str]] = None) -> 'Workspace':
        """
        Get an existing Workspace resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] create_time: 工作区创建时间，RFC3339 格式。
        :param pulumi.Input[builtins.bool] delete_protection_enabled: 是否开启工作区删除保护,true：开启，false：关闭。
        :param pulumi.Input[builtins.str] description: 工作区描述信息，字符串形式，长度限制为 0～200。
        :param pulumi.Input[Union['WorkspaceInstanceTypeArgs', 'WorkspaceInstanceTypeArgsDict']] instance_type: 工作区规格详情。
        :param pulumi.Input[builtins.str] instance_type_id: 工作区规格,vmp.standard.15d：15 天存储时长工作区。vmp.standard.30d：30 天存储时长工作区。vmp.standard.90d：90 天存储时长工作区。vmp.standard.180d：180 天存储时长工作区。vmp.standard.1y：1 年存储时长工作区。
        :param pulumi.Input[builtins.str] name: 工作区名称，字符串形式，长度限制为 1～100。
        :param pulumi.Input[builtins.str] overdue_reclaim_time: 工作区预期欠费回收时间，RFC3339 格式。
        :param pulumi.Input[builtins.str] password: 工作区 BasicAuth 密码。
        :param pulumi.Input[builtins.str] project_name: 项目名称。
        :param pulumi.Input[builtins.str] prometheus_push_intranet_endpoint: 工作区 Push Gateway URL 地址。
        :param pulumi.Input[builtins.str] prometheus_query_intranet_endpoint: 工作区 Query URL 地址。
        :param pulumi.Input[builtins.str] prometheus_write_intranet_endpoint: 工作区 RemoteWrite URL 地址。
        :param pulumi.Input[Union['WorkspaceQuotaArgs', 'WorkspaceQuotaArgsDict']] quota: 工作区配额详情。
        :param pulumi.Input[builtins.str] status: 工作区状态，取值：Creating：创建中 Active：正常 Updating：更新中 Deleting：删除中 OverdueShutted：欠费关停 Resuming：恢复中 Error：错误。
        :param pulumi.Input[Union['WorkspaceUsageArgs', 'WorkspaceUsageArgsDict']] usage: 工作区用量。
        :param pulumi.Input[builtins.str] username: 工作区 BasicAuth 用户名。
        :param pulumi.Input[builtins.str] workspace_id: 工作区Id。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _WorkspaceState.__new__(_WorkspaceState)

        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["delete_protection_enabled"] = delete_protection_enabled
        __props__.__dict__["description"] = description
        __props__.__dict__["instance_type"] = instance_type
        __props__.__dict__["instance_type_id"] = instance_type_id
        __props__.__dict__["name"] = name
        __props__.__dict__["overdue_reclaim_time"] = overdue_reclaim_time
        __props__.__dict__["password"] = password
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["prometheus_push_intranet_endpoint"] = prometheus_push_intranet_endpoint
        __props__.__dict__["prometheus_query_intranet_endpoint"] = prometheus_query_intranet_endpoint
        __props__.__dict__["prometheus_write_intranet_endpoint"] = prometheus_write_intranet_endpoint
        __props__.__dict__["quota"] = quota
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        __props__.__dict__["usage"] = usage
        __props__.__dict__["username"] = username
        __props__.__dict__["workspace_id"] = workspace_id
        return Workspace(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[builtins.str]:
        """
        工作区创建时间，RFC3339 格式。
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="deleteProtectionEnabled")
    def delete_protection_enabled(self) -> pulumi.Output[builtins.bool]:
        """
        是否开启工作区删除保护,true：开启，false：关闭。
        """
        return pulumi.get(self, "delete_protection_enabled")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        工作区描述信息，字符串形式，长度限制为 0～200。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> pulumi.Output['outputs.WorkspaceInstanceType']:
        """
        工作区规格详情。
        """
        return pulumi.get(self, "instance_type")

    @property
    @pulumi.getter(name="instanceTypeId")
    def instance_type_id(self) -> pulumi.Output[builtins.str]:
        """
        工作区规格,vmp.standard.15d：15 天存储时长工作区。vmp.standard.30d：30 天存储时长工作区。vmp.standard.90d：90 天存储时长工作区。vmp.standard.180d：180 天存储时长工作区。vmp.standard.1y：1 年存储时长工作区。
        """
        return pulumi.get(self, "instance_type_id")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        工作区名称，字符串形式，长度限制为 1～100。
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="overdueReclaimTime")
    def overdue_reclaim_time(self) -> pulumi.Output[builtins.str]:
        """
        工作区预期欠费回收时间，RFC3339 格式。
        """
        return pulumi.get(self, "overdue_reclaim_time")

    @property
    @pulumi.getter
    def password(self) -> pulumi.Output[builtins.str]:
        """
        工作区 BasicAuth 密码。
        """
        return pulumi.get(self, "password")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[builtins.str]:
        """
        项目名称。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="prometheusPushIntranetEndpoint")
    def prometheus_push_intranet_endpoint(self) -> pulumi.Output[builtins.str]:
        """
        工作区 Push Gateway URL 地址。
        """
        return pulumi.get(self, "prometheus_push_intranet_endpoint")

    @property
    @pulumi.getter(name="prometheusQueryIntranetEndpoint")
    def prometheus_query_intranet_endpoint(self) -> pulumi.Output[builtins.str]:
        """
        工作区 Query URL 地址。
        """
        return pulumi.get(self, "prometheus_query_intranet_endpoint")

    @property
    @pulumi.getter(name="prometheusWriteIntranetEndpoint")
    def prometheus_write_intranet_endpoint(self) -> pulumi.Output[builtins.str]:
        """
        工作区 RemoteWrite URL 地址。
        """
        return pulumi.get(self, "prometheus_write_intranet_endpoint")

    @property
    @pulumi.getter
    def quota(self) -> pulumi.Output['outputs.WorkspaceQuota']:
        """
        工作区配额详情。
        """
        return pulumi.get(self, "quota")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        工作区状态，取值：Creating：创建中 Active：正常 Updating：更新中 Deleting：删除中 OverdueShutted：欠费关停 Resuming：恢复中 Error：错误。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.WorkspaceTag']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def usage(self) -> pulumi.Output['outputs.WorkspaceUsage']:
        """
        工作区用量。
        """
        return pulumi.get(self, "usage")

    @property
    @pulumi.getter
    def username(self) -> pulumi.Output[builtins.str]:
        """
        工作区 BasicAuth 用户名。
        """
        return pulumi.get(self, "username")

    @property
    @pulumi.getter(name="workspaceId")
    def workspace_id(self) -> pulumi.Output[builtins.str]:
        """
        工作区Id。
        """
        return pulumi.get(self, "workspace_id")

