# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['TransitRouterRouteTableArgs', 'TransitRouterRouteTable']

@pulumi.input_type
class TransitRouterRouteTableArgs:
    def __init__(__self__, *,
                 transit_router_id: pulumi.Input[builtins.str],
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['TransitRouterRouteTableTagArgs']]]] = None,
                 transit_router_route_table_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a TransitRouterRouteTable resource.
        :param pulumi.Input[builtins.str] transit_router_id: 中转路由器实例的ID
        :param pulumi.Input[builtins.str] description: TR路由表的描述信息。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ~ 255个字符。不传入该参数或该参数不传入数值时，默认为空字符串。
        :param pulumi.Input[builtins.str] transit_router_route_table_name: TR路由表的名称。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：点号（.）、下划线（_）和短横线（-）。长度限制为1 ~ 128个字符。不传入该参数或该参数不传入数值时，默认为TR路由表的ID
        """
        pulumi.set(__self__, "transit_router_id", transit_router_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if transit_router_route_table_name is not None:
            pulumi.set(__self__, "transit_router_route_table_name", transit_router_route_table_name)

    @property
    @pulumi.getter(name="transitRouterId")
    def transit_router_id(self) -> pulumi.Input[builtins.str]:
        """
        中转路由器实例的ID
        """
        return pulumi.get(self, "transit_router_id")

    @transit_router_id.setter
    def transit_router_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "transit_router_id", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        TR路由表的描述信息。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ~ 255个字符。不传入该参数或该参数不传入数值时，默认为空字符串。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['TransitRouterRouteTableTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['TransitRouterRouteTableTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="transitRouterRouteTableName")
    def transit_router_route_table_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        TR路由表的名称。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：点号（.）、下划线（_）和短横线（-）。长度限制为1 ~ 128个字符。不传入该参数或该参数不传入数值时，默认为TR路由表的ID
        """
        return pulumi.get(self, "transit_router_route_table_name")

    @transit_router_route_table_name.setter
    def transit_router_route_table_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "transit_router_route_table_name", value)


@pulumi.input_type
class _TransitRouterRouteTableState:
    def __init__(__self__, *,
                 created_time: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 in_route_policy_table_id: Optional[pulumi.Input[builtins.str]] = None,
                 out_route_policy_table_id: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['TransitRouterRouteTableTagArgs']]]] = None,
                 transit_router_id: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_route_table_id: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_route_table_name: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_route_table_type: Optional[pulumi.Input[builtins.str]] = None,
                 updated_time: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering TransitRouterRouteTable resources.
        :param pulumi.Input[builtins.str] created_time: TR路由表的创建时间
        :param pulumi.Input[builtins.str] description: TR路由表的描述信息。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ~ 255个字符。不传入该参数或该参数不传入数值时，默认为空字符串。
        :param pulumi.Input[builtins.str] in_route_policy_table_id: TR路由表关联的收方向路由策略的ID
        :param pulumi.Input[builtins.str] out_route_policy_table_id: TR路由表关联的发方向路由策略的ID
        :param pulumi.Input[builtins.str] status: TR路由表的状态。Creating: 创建中。Deleting: 删除中。Pending：配置中。Available：可用
        :param pulumi.Input[builtins.str] transit_router_id: 中转路由器实例的ID
        :param pulumi.Input[builtins.str] transit_router_route_table_id: TR路由表的ID
        :param pulumi.Input[builtins.str] transit_router_route_table_name: TR路由表的名称。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：点号（.）、下划线（_）和短横线（-）。长度限制为1 ~ 128个字符。不传入该参数或该参数不传入数值时，默认为TR路由表的ID
        :param pulumi.Input[builtins.str] transit_router_route_table_type: TR路由表的类型。System：系统路由表。Custom：自定义路由表。
        :param pulumi.Input[builtins.str] updated_time: TR路由表的最近操作时间
        """
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if in_route_policy_table_id is not None:
            pulumi.set(__self__, "in_route_policy_table_id", in_route_policy_table_id)
        if out_route_policy_table_id is not None:
            pulumi.set(__self__, "out_route_policy_table_id", out_route_policy_table_id)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if transit_router_id is not None:
            pulumi.set(__self__, "transit_router_id", transit_router_id)
        if transit_router_route_table_id is not None:
            pulumi.set(__self__, "transit_router_route_table_id", transit_router_route_table_id)
        if transit_router_route_table_name is not None:
            pulumi.set(__self__, "transit_router_route_table_name", transit_router_route_table_name)
        if transit_router_route_table_type is not None:
            pulumi.set(__self__, "transit_router_route_table_type", transit_router_route_table_type)
        if updated_time is not None:
            pulumi.set(__self__, "updated_time", updated_time)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        TR路由表的创建时间
        """
        return pulumi.get(self, "created_time")

    @created_time.setter
    def created_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_time", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        TR路由表的描述信息。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ~ 255个字符。不传入该参数或该参数不传入数值时，默认为空字符串。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="inRoutePolicyTableId")
    def in_route_policy_table_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        TR路由表关联的收方向路由策略的ID
        """
        return pulumi.get(self, "in_route_policy_table_id")

    @in_route_policy_table_id.setter
    def in_route_policy_table_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "in_route_policy_table_id", value)

    @property
    @pulumi.getter(name="outRoutePolicyTableId")
    def out_route_policy_table_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        TR路由表关联的发方向路由策略的ID
        """
        return pulumi.get(self, "out_route_policy_table_id")

    @out_route_policy_table_id.setter
    def out_route_policy_table_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "out_route_policy_table_id", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        TR路由表的状态。Creating: 创建中。Deleting: 删除中。Pending：配置中。Available：可用
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['TransitRouterRouteTableTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['TransitRouterRouteTableTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="transitRouterId")
    def transit_router_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        中转路由器实例的ID
        """
        return pulumi.get(self, "transit_router_id")

    @transit_router_id.setter
    def transit_router_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "transit_router_id", value)

    @property
    @pulumi.getter(name="transitRouterRouteTableId")
    def transit_router_route_table_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        TR路由表的ID
        """
        return pulumi.get(self, "transit_router_route_table_id")

    @transit_router_route_table_id.setter
    def transit_router_route_table_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "transit_router_route_table_id", value)

    @property
    @pulumi.getter(name="transitRouterRouteTableName")
    def transit_router_route_table_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        TR路由表的名称。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：点号（.）、下划线（_）和短横线（-）。长度限制为1 ~ 128个字符。不传入该参数或该参数不传入数值时，默认为TR路由表的ID
        """
        return pulumi.get(self, "transit_router_route_table_name")

    @transit_router_route_table_name.setter
    def transit_router_route_table_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "transit_router_route_table_name", value)

    @property
    @pulumi.getter(name="transitRouterRouteTableType")
    def transit_router_route_table_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        TR路由表的类型。System：系统路由表。Custom：自定义路由表。
        """
        return pulumi.get(self, "transit_router_route_table_type")

    @transit_router_route_table_type.setter
    def transit_router_route_table_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "transit_router_route_table_type", value)

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        TR路由表的最近操作时间
        """
        return pulumi.get(self, "updated_time")

    @updated_time.setter
    def updated_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_time", value)


@pulumi.type_token("bytepluscc:transitrouter/transitRouterRouteTable:TransitRouterRouteTable")
class TransitRouterRouteTable(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['TransitRouterRouteTableTagArgs', 'TransitRouterRouteTableTagArgsDict']]]]] = None,
                 transit_router_id: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_route_table_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        中转路由器转发流量的依据，具有关联转发、静态路由、路由学习、路由同步等能力。每个TR实例下可以创建多个TR路由表，分别用于转发具有不同访问需求的网络实例的流量。多条网络实例连接可以关联同一个TR路由表。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        transit_router_transit_router_route_table_demo = bytepluscc.transitrouter.TransitRouterRouteTable("TransitRouterTransitRouterRouteTableDemo",
            transit_router_id="tr-mj7mc0paq******",
            description="TransitRouterTransitRouterRouteTableDemo-Description",
            transit_router_route_table_name="TransitRouterTransitRouterRouteTableDemo",
            tags=[{
                "key": "env",
                "value": "test",
            }])
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:transitrouter/transitRouterRouteTable:TransitRouterRouteTable example "transit_router_id|transit_router_route_table_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] description: TR路由表的描述信息。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ~ 255个字符。不传入该参数或该参数不传入数值时，默认为空字符串。
        :param pulumi.Input[builtins.str] transit_router_id: 中转路由器实例的ID
        :param pulumi.Input[builtins.str] transit_router_route_table_name: TR路由表的名称。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：点号（.）、下划线（_）和短横线（-）。长度限制为1 ~ 128个字符。不传入该参数或该参数不传入数值时，默认为TR路由表的ID
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: TransitRouterRouteTableArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        中转路由器转发流量的依据，具有关联转发、静态路由、路由学习、路由同步等能力。每个TR实例下可以创建多个TR路由表，分别用于转发具有不同访问需求的网络实例的流量。多条网络实例连接可以关联同一个TR路由表。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        transit_router_transit_router_route_table_demo = bytepluscc.transitrouter.TransitRouterRouteTable("TransitRouterTransitRouterRouteTableDemo",
            transit_router_id="tr-mj7mc0paq******",
            description="TransitRouterTransitRouterRouteTableDemo-Description",
            transit_router_route_table_name="TransitRouterTransitRouterRouteTableDemo",
            tags=[{
                "key": "env",
                "value": "test",
            }])
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:transitrouter/transitRouterRouteTable:TransitRouterRouteTable example "transit_router_id|transit_router_route_table_id"
        ```

        :param str resource_name: The name of the resource.
        :param TransitRouterRouteTableArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(TransitRouterRouteTableArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['TransitRouterRouteTableTagArgs', 'TransitRouterRouteTableTagArgsDict']]]]] = None,
                 transit_router_id: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_route_table_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = TransitRouterRouteTableArgs.__new__(TransitRouterRouteTableArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["tags"] = tags
            if transit_router_id is None and not opts.urn:
                raise TypeError("Missing required property 'transit_router_id'")
            __props__.__dict__["transit_router_id"] = transit_router_id
            __props__.__dict__["transit_router_route_table_name"] = transit_router_route_table_name
            __props__.__dict__["created_time"] = None
            __props__.__dict__["in_route_policy_table_id"] = None
            __props__.__dict__["out_route_policy_table_id"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["transit_router_route_table_id"] = None
            __props__.__dict__["transit_router_route_table_type"] = None
            __props__.__dict__["updated_time"] = None
        super(TransitRouterRouteTable, __self__).__init__(
            'bytepluscc:transitrouter/transitRouterRouteTable:TransitRouterRouteTable',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            created_time: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            in_route_policy_table_id: Optional[pulumi.Input[builtins.str]] = None,
            out_route_policy_table_id: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['TransitRouterRouteTableTagArgs', 'TransitRouterRouteTableTagArgsDict']]]]] = None,
            transit_router_id: Optional[pulumi.Input[builtins.str]] = None,
            transit_router_route_table_id: Optional[pulumi.Input[builtins.str]] = None,
            transit_router_route_table_name: Optional[pulumi.Input[builtins.str]] = None,
            transit_router_route_table_type: Optional[pulumi.Input[builtins.str]] = None,
            updated_time: Optional[pulumi.Input[builtins.str]] = None) -> 'TransitRouterRouteTable':
        """
        Get an existing TransitRouterRouteTable resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] created_time: TR路由表的创建时间
        :param pulumi.Input[builtins.str] description: TR路由表的描述信息。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ~ 255个字符。不传入该参数或该参数不传入数值时，默认为空字符串。
        :param pulumi.Input[builtins.str] in_route_policy_table_id: TR路由表关联的收方向路由策略的ID
        :param pulumi.Input[builtins.str] out_route_policy_table_id: TR路由表关联的发方向路由策略的ID
        :param pulumi.Input[builtins.str] status: TR路由表的状态。Creating: 创建中。Deleting: 删除中。Pending：配置中。Available：可用
        :param pulumi.Input[builtins.str] transit_router_id: 中转路由器实例的ID
        :param pulumi.Input[builtins.str] transit_router_route_table_id: TR路由表的ID
        :param pulumi.Input[builtins.str] transit_router_route_table_name: TR路由表的名称。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：点号（.）、下划线（_）和短横线（-）。长度限制为1 ~ 128个字符。不传入该参数或该参数不传入数值时，默认为TR路由表的ID
        :param pulumi.Input[builtins.str] transit_router_route_table_type: TR路由表的类型。System：系统路由表。Custom：自定义路由表。
        :param pulumi.Input[builtins.str] updated_time: TR路由表的最近操作时间
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _TransitRouterRouteTableState.__new__(_TransitRouterRouteTableState)

        __props__.__dict__["created_time"] = created_time
        __props__.__dict__["description"] = description
        __props__.__dict__["in_route_policy_table_id"] = in_route_policy_table_id
        __props__.__dict__["out_route_policy_table_id"] = out_route_policy_table_id
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        __props__.__dict__["transit_router_id"] = transit_router_id
        __props__.__dict__["transit_router_route_table_id"] = transit_router_route_table_id
        __props__.__dict__["transit_router_route_table_name"] = transit_router_route_table_name
        __props__.__dict__["transit_router_route_table_type"] = transit_router_route_table_type
        __props__.__dict__["updated_time"] = updated_time
        return TransitRouterRouteTable(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> pulumi.Output[builtins.str]:
        """
        TR路由表的创建时间
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        TR路由表的描述信息。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ~ 255个字符。不传入该参数或该参数不传入数值时，默认为空字符串。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="inRoutePolicyTableId")
    def in_route_policy_table_id(self) -> pulumi.Output[builtins.str]:
        """
        TR路由表关联的收方向路由策略的ID
        """
        return pulumi.get(self, "in_route_policy_table_id")

    @property
    @pulumi.getter(name="outRoutePolicyTableId")
    def out_route_policy_table_id(self) -> pulumi.Output[builtins.str]:
        """
        TR路由表关联的发方向路由策略的ID
        """
        return pulumi.get(self, "out_route_policy_table_id")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        TR路由表的状态。Creating: 创建中。Deleting: 删除中。Pending：配置中。Available：可用
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.TransitRouterRouteTableTag']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="transitRouterId")
    def transit_router_id(self) -> pulumi.Output[builtins.str]:
        """
        中转路由器实例的ID
        """
        return pulumi.get(self, "transit_router_id")

    @property
    @pulumi.getter(name="transitRouterRouteTableId")
    def transit_router_route_table_id(self) -> pulumi.Output[builtins.str]:
        """
        TR路由表的ID
        """
        return pulumi.get(self, "transit_router_route_table_id")

    @property
    @pulumi.getter(name="transitRouterRouteTableName")
    def transit_router_route_table_name(self) -> pulumi.Output[builtins.str]:
        """
        TR路由表的名称。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：点号（.）、下划线（_）和短横线（-）。长度限制为1 ~ 128个字符。不传入该参数或该参数不传入数值时，默认为TR路由表的ID
        """
        return pulumi.get(self, "transit_router_route_table_name")

    @property
    @pulumi.getter(name="transitRouterRouteTableType")
    def transit_router_route_table_type(self) -> pulumi.Output[builtins.str]:
        """
        TR路由表的类型。System：系统路由表。Custom：自定义路由表。
        """
        return pulumi.get(self, "transit_router_route_table_type")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> pulumi.Output[builtins.str]:
        """
        TR路由表的最近操作时间
        """
        return pulumi.get(self, "updated_time")

